import { __decorate } from 'tslib';
import { Pipe, NgModule, EventEmitter, Input, Output, Component, ChangeDetectionStrategy, ElementRef, HostListener, Directive, ViewChild, ChangeDetectorRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { TranslateModule } from '@ngx-translate/core';
import { DomSanitizer } from '@angular/platform-browser';
import { Validators, FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { parsePhoneNumberFromString } from 'libphonenumber-js';
import 'hammerjs';
import Autolinker from 'autolinker';

let VvcSanitizePipe = class VvcSanitizePipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(value, type) {
        switch (type) {
            case 'html': return this.sanitizer.bypassSecurityTrustHtml(value);
            case 'style': return this.sanitizer.bypassSecurityTrustStyle(value);
            case 'script': return this.sanitizer.bypassSecurityTrustScript(value);
            case 'url': return this.sanitizer.bypassSecurityTrustUrl(value);
            case 'resourceUrl': return this.sanitizer.bypassSecurityTrustResourceUrl(value);
            default: return value;
        }
    }
};
VvcSanitizePipe.ctorParameters = () => [
    { type: DomSanitizer }
];
VvcSanitizePipe = __decorate([
    Pipe({ name: 'vvcSanitize' })
], VvcSanitizePipe);

var VvcCommonModule_1;
let VvcCommonModule = VvcCommonModule_1 = class VvcCommonModule {
    static forRoot() {
        return {
            ngModule: VvcCommonModule_1
        };
    }
};
VvcCommonModule = VvcCommonModule_1 = __decorate([
    NgModule({
        imports: [],
        exports: [
            VvcSanitizePipe
        ],
        entryComponents: [],
        declarations: [
            VvcSanitizePipe
        ]
    })
], VvcCommonModule);

let InboundComponent = class InboundComponent {
    constructor() {
        this.close = new EventEmitter();
        this.upgrade = new EventEmitter();
    }
};
__decorate([
    Input()
], InboundComponent.prototype, "context", void 0);
__decorate([
    Output()
], InboundComponent.prototype, "close", void 0);
__decorate([
    Output()
], InboundComponent.prototype, "upgrade", void 0);
InboundComponent = __decorate([
    Component({
        selector: 'vvc-inbound',
        template: "<div id=\"inbound-call\" *ngIf=\"context && context.inboundState\">\n\n  <vvc-inbound-topbar [context]=\"context\"\n                      (close)=\"close.emit()\"></vvc-inbound-topbar>\n\n  <vvc-inbound-fullscreen-messages [context]=\"context\"\n                                   (upgrade)=\"upgrade.emit()\"></vvc-inbound-fullscreen-messages>\n\n  <div class=\"sep\"></div>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], InboundComponent);

let InboundTopbarComponent = class InboundTopbarComponent {
    constructor() {
        this.close = new EventEmitter();
    }
};
__decorate([
    Input()
], InboundTopbarComponent.prototype, "context", void 0);
__decorate([
    Output()
], InboundTopbarComponent.prototype, "close", void 0);
InboundTopbarComponent = __decorate([
    Component({
        selector: 'vvc-inbound-topbar',
        template: "<div class=\"inbound-top-bar\" [ngClass]=\"{ 'closed': context.isClosed  }\">\n  <div class=\"inbound-top-header\">\n    <div class=\"inbound-top-title\"></div>\n  </div>\n  <div class=\"inbound-top-controls\">\n      <span (click)=\"close.emit()\">\n        <i class=\"icon icon-vvc-close\"></i>\n      </span>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], InboundTopbarComponent);

let InboundFullscreenMessagesComponent = class InboundFullscreenMessagesComponent {
    constructor() {
        this.upgrade = new EventEmitter();
    }
    ngOnInit() {
        if (this.context && this.context.inboundState) {
            this.formattedNum = (this.context.variables.showInternationalNumber) ? this.context.inboundState.international : this.context.inboundState.formatted;
        }
        this.numtel = (this.context &&
            this.context.inboundState &&
            this.context.inboundState.extCode) ? 'tel:' + this.context.inboundState.dnis + "," + this.context.inboundState.extCode
            : 'tel:' + this.context.inboundState.dnis;
    }
};
__decorate([
    Input()
], InboundFullscreenMessagesComponent.prototype, "context", void 0);
__decorate([
    Output()
], InboundFullscreenMessagesComponent.prototype, "upgrade", void 0);
InboundFullscreenMessagesComponent = __decorate([
    Component({
        selector: 'vvc-inbound-fullscreen-messages',
        template: "<div *ngIf=\"context && context.inboundState\">\n  <div class=\"inbound-icon-wrapper\" *ngIf=\"!context.isClosed\">\n\n    <div class=\"inbound-icon\" *ngIf=\"context.isMobile && context.inboundState.state === 'compose'\">\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"80\" height=\"80\" viewBox=\"0 0 80 80\">\n        <g fill=\"none\" fill-rule=\"evenodd\">\n          <circle cx=\"40\" cy=\"40\" r=\"40\" fill=\"#F1F3F7\" fill-rule=\"nonzero\"/>\n          <path fill-rule=\"nonzero\" d=\"M55.2536087,10 C56.7703987,10 58,11.2324678 58,12.7531462 L58,68.2535055 C58,69.7086854 56.8597936,70.9081146 55.4209112,70.994965 L55.2536087,71 L25.4030044,71 C23.523577,71 22,69.5223514 22,67.6987466 L22,13.3012534 C22,11.4780215 23.523881,10 25.4030044,10 L55.2536087,10 Z M42.0001925,66 L38.9998075,66 C38.4437166,66 38,66.4477153 38,67 C38,67.5164112 38.3859659,67.9360179 38.8832088,67.993327 L38.9998075,68 L42.0001925,68 C42.5165626,68 42.9360386,67.6139598 42.9933292,67.1166211 L43,67 L42.9932736,66.8826674 C42.9355196,66.3827202 42.5129296,66 42.0001925,66 Z M56,18 L24,18 L24,64 L56,64 L56,18 Z M34.5,33.5 C35.05,33.5 35.5,33.95 35.5,34.5 C35.5,35.75 35.7,36.95 36.07,38.07 C36.18,38.42 36.1,38.81 35.82,39.07 L35.82,39.07 L33.62,41.28 C35.06,44.12 37.38,46.43 40.21,47.87 L40.21,47.87 L42.41,45.67 C42.69,45.4 43.08,45.32 43.43,45.43 C44.55,45.8 45.75,46 47,46 C47.55,46 48,46.45 48,47 L48,47 L48,50.5 C48,51.05 47.55,51.5 47,51.5 C37.61,51.5 30,43.89 30,34.5 C30,33.95 30.45,33.5 31,33.5 L31,33.5 Z M47.5,32 L47.5,36 L50.5,36 L45.5,41 L40.5,36 L43.5,36 L43.5,32 L47.5,32 Z M49.4917959,14 L31.5082041,14 C31.2266151,14 31,14.2238576 31,14.5 C31,14.7680664 31.2275307,15 31.5082041,15 L31.5082041,15 L49.4917959,15 C49.7733849,15 50,14.7761424 50,14.5 L50,14.5 L49.9918122,14.4122514 C49.9487815,14.1832562 49.7412833,14 49.4917959,14 L49.4917959,14 Z\"/>\n        </g>\n      </svg>\n    </div>\n\n    <div class=\"inbound-icon\" *ngIf=\"!context.isMobile && context.inboundState.state === 'compose'\">\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"80\" height=\"80\" viewBox=\"0 0 80 80\">\n        <g fill=\"none\" fill-rule=\"evenodd\">\n          <circle cx=\"40\" cy=\"40\" r=\"40\" fill=\"#F1F3F7\" fill-rule=\"nonzero\"/>\n          <path fill-rule=\"nonzero\" d=\"M33.2536087,0 C34.7703987,0 36,1.23246777 36,2.75314617 L36,58.2535055 C36,59.7086854 34.8597936,60.9081146 33.4209112,60.994965 L33.2536087,61 L3.40300443,61 C1.52357698,61 0,59.5223514 0,57.6987466 L0,3.30125343 C0,1.47802151 1.52388103,0 3.40300443,0 L33.2536087,0 Z M20.0001925,56 L16.9998075,56 C16.4437166,56 16,56.4477153 16,57 C16,57.5164112 16.3859659,57.9360179 16.8832088,57.993327 L16.9998075,58 L20.0001925,58 C20.5165626,58 20.9360386,57.6139598 20.9933292,57.1166211 L21,57 L20.9932736,56.8826674 C20.9355196,56.3827202 20.5129296,56 20.0001925,56 Z M34,8 L2,8 L2,54 L34,54 L34,8 Z M18,45.8333333 C19.4019536,45.8333333 20.5384615,46.9899311 20.5384615,48.4166667 C20.5384615,49.8434023 19.4019536,51 18,51 C16.5980464,51 15.4615385,49.8434023 15.4615385,48.4166667 C15.4615385,46.9899311 16.5980464,45.8333333 18,45.8333333 Z M9.53846154,37.2222222 C10.9404151,37.2222222 12.0769231,38.37882 12.0769231,39.8055556 C12.0769231,41.2322912 10.9404151,42.3888889 9.53846154,42.3888889 C8.13650794,42.3888889 7,41.2322912 7,39.8055556 C7,38.37882 8.13650794,37.2222222 9.53846154,37.2222222 Z M18,37.2222222 C19.4019536,37.2222222 20.5384615,38.37882 20.5384615,39.8055556 C20.5384615,41.2322912 19.4019536,42.3888889 18,42.3888889 C16.5980464,42.3888889 15.4615385,41.2322912 15.4615385,39.8055556 C15.4615385,38.37882 16.5980464,37.2222222 18,37.2222222 Z M26.4615385,37.2222222 C27.8634921,37.2222222 29,38.37882 29,39.8055556 C29,41.2322912 27.8634921,42.3888889 26.4615385,42.3888889 C25.0595849,42.3888889 23.9230769,41.2322912 23.9230769,39.8055556 C23.9230769,38.37882 25.0595849,37.2222222 26.4615385,37.2222222 Z M9.53846154,28.6111111 C10.9404151,28.6111111 12.0769231,29.7677088 12.0769231,31.1944444 C12.0769231,32.62118 10.9404151,33.7777778 9.53846154,33.7777778 C8.13650794,33.7777778 7,32.62118 7,31.1944444 C7,29.7677088 8.13650794,28.6111111 9.53846154,28.6111111 Z M18,28.6111111 C19.4019536,28.6111111 20.5384615,29.7677088 20.5384615,31.1944444 C20.5384615,32.62118 19.4019536,33.7777778 18,33.7777778 C16.5980464,33.7777778 15.4615385,32.62118 15.4615385,31.1944444 C15.4615385,29.7677088 16.5980464,28.6111111 18,28.6111111 Z M26.4615385,28.6111111 C27.8634921,28.6111111 29,29.7677088 29,31.1944444 C29,32.62118 27.8634921,33.7777778 26.4615385,33.7777778 C25.0595849,33.7777778 23.9230769,32.62118 23.9230769,31.1944444 C23.9230769,29.7677088 25.0595849,28.6111111 26.4615385,28.6111111 Z M9.53846154,20 C10.9404151,20 12.0769231,21.1565977 12.0769231,22.5833333 C12.0769231,24.0100689 10.9404151,25.1666667 9.53846154,25.1666667 C8.13650794,25.1666667 7,24.0100689 7,22.5833333 C7,21.1565977 8.13650794,20 9.53846154,20 Z M18,20 C19.4019536,20 20.5384615,21.1565977 20.5384615,22.5833333 C20.5384615,24.0100689 19.4019536,25.1666667 18,25.1666667 C16.5980464,25.1666667 15.4615385,24.0100689 15.4615385,22.5833333 C15.4615385,21.1565977 16.5980464,20 18,20 Z M26.4615385,20 C27.8634921,20 29,21.1565977 29,22.5833333 C29,24.0100689 27.8634921,25.1666667 26.4615385,25.1666667 C25.0595849,25.1666667 23.9230769,24.0100689 23.9230769,22.5833333 C23.9230769,21.1565977 25.0595849,20 26.4615385,20 Z M27.4917959,4 L9.5082041,4 C9.22661515,4 9,4.22385763 9,4.5 C9,4.76806641 9.22753073,5 9.5082041,5 L9.5082041,5 L27.4917959,5 C27.7733849,5 28,4.77614237 28,4.5 L28,4.5 L27.9918122,4.41225137 C27.9487815,4.18325617 27.7412833,4 27.4917959,4 L27.4917959,4 Z\" transform=\"translate(22 10)\"/>\n        </g>\n      </svg>\n    </div>\n\n    <div class=\"inbound-icon circle\" *ngIf=\"context.inboundState.state === 'answer'\">\n      <svg height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n    </div>\n  </div>\n\n  <div class=\"inbound-message-wrapper\" *ngIf=\"!context.isClosed\">\n    <div class=\"inbound-mode\" *ngIf=\"context.isMobile && context.inboundState.state === 'compose'\">\n      <div class=\"status-message\"\n           [innerHTML]=\" 'STRINGS.INBOUND.CLICK_TO_CALL' | translate | vvcSanitize:'html'\"></div>\n      <div class=\"number-to-call\">\n        <a [href]=\"numtel\" target=\"_blank\">{{formattedNum}}</a>\n      </div>\n    </div>\n\n    <div class=\"inbound-mode\" *ngIf=\"!context.isMobile && context.inboundState.state === 'compose'\">\n      <div class=\"status-message\"\n           [innerHTML]=\" 'STRINGS.INBOUND.COMPOSE_TO_CALL' | translate | vvcSanitize:'html'\"></div>\n      <div class=\"number-to-call\">\n        <span>{{formattedNum}}</span>\n      </div>\n      <div *ngIf=\"context.inboundState.extCode\">\n        <div class=\"status-message\"\n             [innerHTML]=\" 'STRINGS.INBOUND.INSERT_EXT_CODE' | translate | vvcSanitize:'html'\"></div>\n        <div class=\"number-to-call\">\n          <span>{{context.inboundState.extCode}}</span>\n        </div>\n      </div>\n    </div>\n\n    <div class=\"inbound-mode\" *ngIf=\"context.inboundState.state === 'answer'\">\n      <div class=\"status-message\"\n           [innerHTML]=\" 'STRINGS.CBN.INLINE' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \">\n      </div>\n\n      <div class=\"status-message\" *ngIf=\"context.notRead > 0\">\n        <div class=\"media-bottom animated slideInLeft\">\n          <div class=\"chat-button\"\n               (click)=\"upgrade.emit()\">\n            <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"20\" viewBox=\"0 0 20 20\" width=\"34\"><defs><path id=\"a\" d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-14 7h12v2h-12zm8 5h-8v-2h8zm4-6h-12v-2h12z\"/><mask id=\"b\" fill=\"#fff\"><use fill=\"none\" xlink:href=\"#a\"/></mask></defs><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><use fill=\"#FFF\" fill-rule=\"nonzero\" xlink:href=\"#a\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#b)\"><path d=\"m0 0h24v24h-24z\"/></g></g>\n              <circle *ngIf=\"context.notRead > 0\" fill=\"#D7293B\" cx=\"21\" cy=\"5\" r=\"5\"></circle>\n            </svg>\n            <span>{{ 'STRINGS.VOICE.OPEN_CHAT' | translate }}</span>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"inbound-icon-wrapper\" *ngIf=\"context.isClosed\">\n    <div class=\"inbound-icon circle closed\">\n      <svg height=\"8\" viewBox=\"0 0 22 8\" width=\"22\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-1 -8)\"><path d=\"m0 0h24.000001v24.000001h-24.000001zm0 0h24.000001v24.000001h-24.000001z\"></path><path d=\"m7.83689909 10.3913551v2.7170978c0 .3458124-.19583633.6360478-.48643218.7842532-.94127785.4631416-1.8257 1.0806639-2.61536263 1.8525666-.34745156.3396372-.91600865.3396372-1.26346021 0l-2.21105536-2.1613277c-.34745156-.3396373-.34745156-.8954073 0-1.2350445 5.93194567-5.79853359 15.54687789-5.79853359 21.47882349 0 .3474516.3396372.3474516.8954072 0 1.2350445l-2.204738 2.1551525c-.3474516.3396372-.9160087.3396372-1.2634602 0-.7833454-.7657275-1.6740848-1.389425-2.6153627-1.8525667-.2969131-.1420301-.4927494-.4446159-.4927494-.7780779v-2.7170978c-2.7038049-.85218066-5.6287153-.85835588-8.32620281 0z\" fill-rule=\"nonzero\"></path></g></svg>\n    </div>\n  </div>\n\n  <div class=\"inbound-message-wrapper\" *ngIf=\"context.isClosed\">\n    <div class=\"status-message\"\n         [innerHTML]=\" 'STRINGS.CBN.LEFT' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \">\n    </div>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], InboundFullscreenMessagesComponent);

let InboundModule = class InboundModule {
};
InboundModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            VvcCommonModule
        ],
        exports: [InboundComponent],
        declarations: [
            InboundComponent,
            InboundTopbarComponent,
            InboundFullscreenMessagesComponent
        ]
    })
], InboundModule);

let CbnComponent = class CbnComponent {
    constructor() {
        this.minimized = new EventEmitter();
        this.close = new EventEmitter();
        this.upgrade = new EventEmitter();
        this.isMinimized = false;
    }
};
__decorate([
    Input()
], CbnComponent.prototype, "context", void 0);
__decorate([
    Output()
], CbnComponent.prototype, "minimized", void 0);
__decorate([
    Output()
], CbnComponent.prototype, "close", void 0);
__decorate([
    Output()
], CbnComponent.prototype, "upgrade", void 0);
CbnComponent = __decorate([
    Component({
        selector: 'vvc-cbn',
        template: "<div id=\"cbn-call\">\n  <vvc-cbn-topbar [context]=\"context\"\n                  (minimize)=\"minimized.emit()\"\n                  (close)=\"close.emit()\"></vvc-cbn-topbar>\n\n  <vvc-cbn-fullscreen-messages [context]=\"context\"\n                               (upgrade)=\"upgrade.emit()\"></vvc-cbn-fullscreen-messages>\n\n  <div class=\"sep\"></div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], CbnComponent);

let CbnMinimizedComponent = class CbnMinimizedComponent {
    constructor() {
        this.expand = new EventEmitter();
        this.close = new EventEmitter();
    }
};
__decorate([
    Input()
], CbnMinimizedComponent.prototype, "context", void 0);
__decorate([
    Output()
], CbnMinimizedComponent.prototype, "expand", void 0);
__decorate([
    Output()
], CbnMinimizedComponent.prototype, "close", void 0);
CbnMinimizedComponent = __decorate([
    Component({
        selector: 'vvc-cbn-minimized',
        template: "<vvc-cbn-topbar [showMessages]=\"true\"\n                [context]=\"context\"\n                (maximize)=\"expand.emit()\"\n                (close)=\"close.emit()\"></vvc-cbn-topbar>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], CbnMinimizedComponent);

let CbnTopbarComponent = class CbnTopbarComponent {
    constructor() {
        this.minimize = new EventEmitter();
        this.maximize = new EventEmitter();
        this.close = new EventEmitter();
    }
};
__decorate([
    Input()
], CbnTopbarComponent.prototype, "context", void 0);
__decorate([
    Input()
], CbnTopbarComponent.prototype, "showMessages", void 0);
__decorate([
    Output()
], CbnTopbarComponent.prototype, "minimize", void 0);
__decorate([
    Output()
], CbnTopbarComponent.prototype, "maximize", void 0);
__decorate([
    Output()
], CbnTopbarComponent.prototype, "close", void 0);
CbnTopbarComponent = __decorate([
    Component({
        selector: 'vvc-cbn-topbar',
        template: "<div class=\"cbn-top-bar\" [ngClass]=\"{ 'closed': context.isClosed && showMessages }\">\n  <div class=\"cbn-top-header\" (click)=\"maximize.emit()\">\n    <div class=\"cbn-top-title\" *ngIf=\"showMessages\">\n      <vvc-cbn-minimized-messages [context]=\"context\"></vvc-cbn-minimized-messages>\n    </div>\n  </div>\n  <div class=\"cbn-top-controls\" *ngIf=\"!showMessages\">\n      <span (click)=\"minimize.emit()\">\n        <i class=\"icon icon-vvc-reduce\"></i>\n      </span>\n  </div>\n  <div class=\"cbn-top-controls\">\n      <span (click)=\"close.emit()\">\n      <i class=\"icon icon-vvc-close\"></i>\n    </span>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], CbnTopbarComponent);

let CbnFullscreenMessagesComponent = class CbnFullscreenMessagesComponent {
    constructor() {
        this.upgrade = new EventEmitter();
    }
};
__decorate([
    Input()
], CbnFullscreenMessagesComponent.prototype, "context", void 0);
__decorate([
    Output()
], CbnFullscreenMessagesComponent.prototype, "upgrade", void 0);
CbnFullscreenMessagesComponent = __decorate([
    Component({
        selector: 'vvc-cbn-fullscreen-messages',
        template: "<div class=\"cbn-icon-wrapper\" *ngIf=\"!context.isClosed\">\n  <div class=\"cbn-icon\" *ngIf=\"!context.cbnState\">\n    <svg height=\"20\" viewBox=\"0 0 22 20\" width=\"22\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m20 0h-18c-1.1 0-2 .9-2 2v12c0 1.1.9 2 2 2h7v2h-2v2h8v-2h-2v-2h7c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm0 14h-18v-12h18zm-5-9c1.1 0 2 .9 2 2s-.9 2-2 2-2-.9-2-2 .9-2 2-2zm4 8h-8v-1c0-1.33 2.67-2 4-2s4 .67 4 2z\" fill=\"#0351a1\" fill-rule=\"evenodd\" transform=\"\"></path></svg>\n  </div>\n  <div class=\"cbn-icon\" *ngIf=\"context.cbnState === 'dialing'\">\n    <div class=\"cbn-icon-layer pulse2 animated2 infinite\"></div>\n    <svg class=\"animated2 infinite shake2\" height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n  </div>\n  <div class=\"cbn-icon\" *ngIf=\"context.cbnState === 'busy'\">\n    <svg height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n  </div>\n  <div class=\"cbn-icon\" *ngIf=\"context.cbnState === 'no-answer'\">\n    <svg height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n  </div>\n  <div class=\"cbn-icon\" *ngIf=\"context.cbnState === 'failed'\">\n    <svg height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n  </div>\n  <div class=\"cbn-icon\" *ngIf=\"context.cbnState === 'answer'\">\n    <svg height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n  </div>\n</div>\n\n<div class=\"cbn-icon-wrapper\" *ngIf=\"context.isClosed\">\n  <div class=\"cbn-icon closed\">\n    <svg height=\"8\" viewBox=\"0 0 22 8\" width=\"22\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-1 -8)\"><path d=\"m0 0h24.000001v24.000001h-24.000001zm0 0h24.000001v24.000001h-24.000001z\"></path><path d=\"m7.83689909 10.3913551v2.7170978c0 .3458124-.19583633.6360478-.48643218.7842532-.94127785.4631416-1.8257 1.0806639-2.61536263 1.8525666-.34745156.3396372-.91600865.3396372-1.26346021 0l-2.21105536-2.1613277c-.34745156-.3396373-.34745156-.8954073 0-1.2350445 5.93194567-5.79853359 15.54687789-5.79853359 21.47882349 0 .3474516.3396372.3474516.8954072 0 1.2350445l-2.204738 2.1551525c-.3474516.3396372-.9160087.3396372-1.2634602 0-.7833454-.7657275-1.6740848-1.389425-2.6153627-1.8525667-.2969131-.1420301-.4927494-.4446159-.4927494-.7780779v-2.7170978c-2.7038049-.85218066-5.6287153-.85835588-8.32620281 0z\" fill-rule=\"nonzero\"></path></g></svg>\n  </div>\n</div>\n<div class=\"cbn-message-wrapper\" *ngIf=\"context.isClosed\">\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.LEFT' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \">\n  </div>\n</div>\n\n<div class=\"cbn-message-wrapper\" *ngIf=\"!context.isClosed\">\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.SUCCESS' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"!context.cbnState\">\n    <!--\n    You will be contacted shortly.<br>\n    Please keep your phone next to you.<br><br>\n    Don't close this window during the contact.\n    <br><br>\n    -->\n  </div>\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.RING' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"context.cbnState === 'dialing'\">\n    <!--\n    Your phone is ringing...<br><br>\n    Don't close this window during the contact.\n    <br><br>\n    -->\n  </div>\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.BUSY' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"context.cbnState === 'busy'\">\n  </div>\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.NOANSWER' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"context.cbnState === 'no-answer'\">\n  </div>\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.WRONG_NUMBER' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"context.cbnState === 'failed'\">\n  </div>\n  <div class=\"status-message\"\n       [innerHTML]=\" 'STRINGS.CBN.INLINE' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"\n       *ngIf=\"context.cbnState === 'answer'\">\n  </div>\n\n  <div class=\"status-message\" *ngIf=\"context.notRead > 0\">\n    <div class=\"media-bottom animated slideInLeft\">\n      <div class=\"chat-button\"\n           (click)=\"upgrade.emit()\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"20\" viewBox=\"0 0 20 20\" width=\"34\"><defs><path id=\"a\" d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-14 7h12v2h-12zm8 5h-8v-2h8zm4-6h-12v-2h12z\"/><mask id=\"b\" fill=\"#fff\"><use fill=\"none\" xlink:href=\"#a\"/></mask></defs><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><use fill=\"#FFF\" fill-rule=\"nonzero\" xlink:href=\"#a\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#b)\"><path d=\"m0 0h24v24h-24z\"/></g></g>\n          <circle *ngIf=\"context.notRead > 0\" fill=\"#D7293B\" cx=\"21\" cy=\"5\" r=\"5\"></circle>\n        </svg>\n        <span>{{ 'STRINGS.VOICE.OPEN_CHAT' | translate }}</span>\n      </div>\n    </div>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], CbnFullscreenMessagesComponent);

let CbnMinimizedMessagesComponent = class CbnMinimizedMessagesComponent {
};
__decorate([
    Input()
], CbnMinimizedMessagesComponent.prototype, "context", void 0);
CbnMinimizedMessagesComponent = __decorate([
    Component({
        selector: 'vvc-cbn-minimized-messages',
        template: "<div *ngIf=\"context.isClosed\">\n  <span [innerHTML]=\" 'STRINGS.CBN.LEFT_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n</div>\n<div *ngIf=\"!context.isClosed && context.notRead === 0\">\n\n  <div *ngIf=\"!context.cbnState\">\n    <span [innerHTML]=\" 'STRINGS.CBN.SUCCESS_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n  <div *ngIf=\"context.cbnState === 'dialing'\">\n    <svg class=\"animated2 infinite shake2\" height=\"19\" viewBox=\"0 0 24 19\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m23.71 14.67c-3.05-2.89-7.17-4.67-11.71-4.67s-8.66 1.78-11.71 4.67c-.18.18-.29.43-.29.71s.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71 0-.27-.11-.52-.29-.7zm-3.96-11.82-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zm-6.75-2.85h-2v5h2zm-6.6 7.81 1.41-1.41-3.55-3.56-1.42 1.42c.11.03 3.56 3.55 3.56 3.55z\" fill=\"#ffffff\" fill-rule=\"evenodd\" transform=\"\"/></svg>\n    <span style=\"padding-left: 10px\" [innerHTML]=\" 'STRINGS.CBN.RING_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n  <div *ngIf=\"context.cbnState === 'busy'\">\n    <span [innerHTML]=\" 'STRINGS.CBN.BUSY_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n  <div *ngIf=\"context.cbnState === 'no-answer'\">\n    <span [innerHTML]=\" 'STRINGS.CBN.NOANSWER_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n  <div *ngIf=\"context.cbnState === 'failed'\">\n    <span [innerHTML]=\" 'STRINGS.CBN.WRONG_NUMBER_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n  <div *ngIf=\"context.cbnState === 'answer'\">\n    <span [innerHTML]=\" 'STRINGS.CBN.INLINE_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n  </div>\n\n</div>\n<div *ngIf=\"!context.isClosed && context.notRead > 0\">\n  <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"18\" viewBox=\"0 0 20 20\" width=\"34\"><defs><path id=\"a\" d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-14 7h12v2h-12zm8 5h-8v-2h8zm4-6h-12v-2h12z\"/><mask id=\"b\" fill=\"#fff\"><use fill=\"none\" xlink:href=\"#a\"/></mask></defs><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><use fill=\"#FFF\" fill-rule=\"nonzero\" xlink:href=\"#a\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#b)\"><path d=\"m0 0h24v24h-24z\"/></g></g>\n    <circle fill=\"#D7293B\" cx=\"21\" cy=\"5\" r=\"5\"></circle>\n  </svg>\n  <span style=\"padding-left: 10px\" [innerHTML]=\" 'STRINGS.CBN.NEW_MESSAGES_M' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></span>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], CbnMinimizedMessagesComponent);

let CbnModule = class CbnModule {
};
CbnModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            VvcCommonModule
        ],
        exports: [CbnComponent, CbnMinimizedComponent],
        declarations: [
            CbnComponent,
            CbnMinimizedComponent,
            CbnTopbarComponent,
            CbnFullscreenMessagesComponent,
            CbnMinimizedMessagesComponent
        ]
    })
], CbnModule);

let VvcAutoScrollDirective = class VvcAutoScrollDirective {
    constructor(element) {
        this.lockYOffset = 10;
        this.observeAttributes = "false";
        this._isLocked = false;
        this.nativeElement = element.nativeElement;
    }
    getObserveAttributes() {
        return this.observeAttributes !== "" && this.observeAttributes.toLowerCase() !== "false";
    }
    ngAfterContentInit() {
        this.mutationObserver = new MutationObserver(() => {
            if (!this._isLocked) {
                this.scrollDown();
            }
        });
        this.mutationObserver.observe(this.nativeElement, {
            childList: true,
            subtree: true,
            attributes: this.getObserveAttributes(),
        });
    }
    ngOnDestroy() {
        this.mutationObserver.disconnect();
    }
    forceScrollDown() {
        this.scrollDown();
    }
    isLocked() {
        return this._isLocked;
    }
    scrollDown() {
        this.nativeElement.scrollTop = this.nativeElement.scrollHeight;
    }
    scrollHandler() {
        const scrollFromBottom = this.nativeElement.scrollHeight - this.nativeElement.scrollTop - this.nativeElement.clientHeight;
        this._isLocked = scrollFromBottom > this.lockYOffset;
    }
};
VvcAutoScrollDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input("lock-y-offset")
], VvcAutoScrollDirective.prototype, "lockYOffset", void 0);
__decorate([
    Input("observe-attributes")
], VvcAutoScrollDirective.prototype, "observeAttributes", void 0);
__decorate([
    HostListener("scroll")
], VvcAutoScrollDirective.prototype, "scrollHandler", null);
VvcAutoScrollDirective = __decorate([
    Directive({
        selector: "[vvc-auto-scroll]",
    })
], VvcAutoScrollDirective);

let ChatComponent = class ChatComponent {
    set context(context) {
        this._context = context;
        if (this._context.messages && this._context.messages.length && this._context.messages.length != this.msgCounter) {
            this.msgCounter = this._context.messages.length;
            this.forceScrollDown();
        }
    }
    ;
    get context() {
        return this._context;
    }
    forceScrollDown() {
        setTimeout(() => {
            this.vvcAutoScroll.forceScrollDown();
        }, 100);
    }
};
__decorate([
    ViewChild(VvcAutoScrollDirective, { static: true })
], ChatComponent.prototype, "vvcAutoScroll", void 0);
__decorate([
    Input()
], ChatComponent.prototype, "context", null);
ChatComponent = __decorate([
    Component({
        selector: 'vvc-chat',
        template: "<div id=\"vvc-emoji-panel\" [style.display]=\"context.showEmojiPanel ? 'flex' : 'none'\">\n  <ng-content select=\"'.vvc-emoji-panel\"></ng-content>\n</div>\n<div id=\"vvc-upload-panel\" [style.display]=\"context.showUploadPanel ? 'flex' : 'none'\">\n  <ng-content select=\"'.vvc-upload-panel\"></ng-content>\n</div>\n<div id=\"vvc-messages\" [style.display]=\"(!context.showEmojiPanel && !context.showUploadPanel) ? 'flex' : 'none'\" vvc-auto-scroll lock-y-offset=\"10\">\n  <ng-content select=\"'.vvc-messages'\"></ng-content>\n</div>\n<div id=\"vvc-is-writing\">\n  <ng-content select=\"'.vvc-is-writing'\"></ng-content>\n</div>\n<div id=\"vvc-chat-box-area\">\n  <ng-content select=\"'.vvc-chat-box-area'\"></ng-content>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ChatComponent);

let ChatAreaComponent = class ChatAreaComponent {
    constructor() {
        this.onSendText = new EventEmitter();
        this.toggleEmojiPanel = new EventEmitter();
        this.showUploadPanel = new EventEmitter();
        this.isVisitorWriting = new EventEmitter();
        this.isWritingTimeout = 20000;
    }
    appendText(value) {
        this.box.nativeElement.value += value;
        this.box.nativeElement.focus();
    }
    canShowUpload() {
        return (this.context &&
            this.context.canUploadFile &&
            !this.context.isAutoChat &&
            !(this.context.variables.hideUploadWithBot && this.context.agent.is_bot));
    }
    clearIsWriting() {
        clearTimeout(this.isWritingTimer);
        this.isWritingTimer = null;
    }
    isWriting() {
        if (!this.isWritingTimer) {
            this.isVisitorWriting.emit();
            this.isWritingTimer = setTimeout(() => {
                this.clearIsWriting();
            }, this.isWritingTimeout);
        }
    }
    showUpload() {
        if (this.readonly) {
            return;
        }
        this.showUploadPanel.emit();
    }
    toggleEmoji() {
        if (this.readonly) {
            return;
        }
        this.toggleEmojiPanel.emit();
    }
    sendText(value) {
        if (this.readonly) {
            return;
        }
        if (value !== '') {
            this.onSendText.emit(value);
            this.clearIsWriting();
        }
    }
};
__decorate([
    ViewChild('box', { static: true })
], ChatAreaComponent.prototype, "box", void 0);
__decorate([
    Input()
], ChatAreaComponent.prototype, "context", void 0);
__decorate([
    Input()
], ChatAreaComponent.prototype, "readonly", void 0);
__decorate([
    Output()
], ChatAreaComponent.prototype, "onSendText", void 0);
__decorate([
    Output()
], ChatAreaComponent.prototype, "toggleEmojiPanel", void 0);
__decorate([
    Output()
], ChatAreaComponent.prototype, "showUploadPanel", void 0);
__decorate([
    Output()
], ChatAreaComponent.prototype, "isVisitorWriting", void 0);
ChatAreaComponent = __decorate([
    Component({
        selector: 'vvc-chat-area',
        template: "<div id=\"vvc-box-inner\">\n  <div class=\"text-box\">\n    <input [readonly]=\"readonly\"\n           [placeholder]=\"'STRINGS.TEXTAREA.PLACEHOLDER' | translate\"\n           type=\"text\"\n           #box\n           (keyup)=\"isWriting()\"\n           (keyup.enter)=\"sendText(box.value);box.value=''\">\n  </div>\n  <div *ngIf=\"canShowUpload()\"\n       (click)=\"showUpload()\"\n       class=\"upload-handler\">\n    <i class=\"icon icon-vvc-clip\"></i>\n  </div>\n  <div *ngIf=\"context.variables.showEmojiButton\"\n       (click)=\"toggleEmoji()\"\n       class=\"emoji-handler\">\n    <i class=\"icon icon-vvc-emoji\"></i>\n  </div>\n  <div class=\"send-button\" (click)=\"sendText(box.value);box.value='';box.focus()\">\n    <div class=\"send-icon\">\n      <i class=\"icon icon-vvc-send\"></i>\n    </div>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ChatAreaComponent);

let ChatIsWritingComponent = class ChatIsWritingComponent {
};
__decorate([
    Input()
], ChatIsWritingComponent.prototype, "context", void 0);
ChatIsWritingComponent = __decorate([
    Component({
        selector: 'vvc-chat-is-writing',
        template: "<div class=\"chat-is-writing-inner animated\" [ngClass]=\"{'fadeInUp': context.isWriting}\">\n  <div class=\"iw-avatar\" *ngIf=\"context.variables.showAvatarOnIsWriting && context.agent.avatar\"><img [src]=\"context.agent.avatar\"></div>\n  <div class=\"iw-message\" [innerHtml]=\"'STRINGS.CHAT.ISWRITING' | translate:{ nickname: context.agent.nick} | vvcSanitize:'html' \"></div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ChatIsWritingComponent);

let ChatModule = class ChatModule {
};
ChatModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            VvcCommonModule
        ],
        exports: [ChatComponent, ChatAreaComponent, ChatIsWritingComponent, VvcAutoScrollDirective],
        declarations: [ChatComponent, ChatAreaComponent, ChatIsWritingComponent, VvcAutoScrollDirective]
    })
], ChatModule);

let EmojiPanelComponent = class EmojiPanelComponent {
    constructor() {
        this.toggleEmojiPanel = new EventEmitter();
        this.addEmoji = new EventEmitter();
        this.emojis = ['😀', '😬', '😁', '😂', '😃', '😄', '😅', '😆', '😇', '😉', '😊', '🙂', '🙃', '☺️', '😋',
            '😌', '😍', '😘', '😗', '😙', '😚', '😜', '😝', '😛', '🤑', '🤓', '😎', '🤗', '😏', '😶',
            '😐', '😑', '😒', '🙄', '🤔', '😳', '😞', '😟', '😠', '😡', '😔', '😕', '🙁', '☹️', '😣',
            '😖', '😫', '😩', '😤', '😮', '😱', '😨', '😰', '😯', '😦', '😧', '😢', '😥', '😪', '😓',
            '😵', '😲', '🤐', '😷', '🤒', '🤕', '😴', '💤', '💩', '😈', '👿', '👹', '👺', '💀', '👻', '👽', '🤖'];
    }
};
__decorate([
    Output()
], EmojiPanelComponent.prototype, "toggleEmojiPanel", void 0);
__decorate([
    Output()
], EmojiPanelComponent.prototype, "addEmoji", void 0);
EmojiPanelComponent = __decorate([
    Component({
        selector: 'vvc-emoji-panel',
        template: "<div class=\"vvc-emoji-container\">\n  <span class=\"emoji\" *ngFor=\"let em of emojis\" (click)=\"addEmoji.emit(em)\">{{em}}</span>\n</div>\n<div class=\"emoji-close-wrapper\">\n  <button class=\"close\" (click)=\"toggleEmojiPanel.emit()\">{{ 'STRINGS.EMOJI.CLOSE_PANEL' | translate }}</button>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], EmojiPanelComponent);

let UploadPanelComponent = class UploadPanelComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.close = new EventEmitter();
        this.upload = new EventEmitter();
    }
    set context(context) {
        if (this._context && this._context.showUploadPanel === false) {
            this.uploadFile = undefined;
            this.dataFile = undefined;
            this.isImage = undefined;
        }
        this._context = Object.assign({}, context);
    }
    ;
    get context() {
        return this._context;
    }
    doUpload(inputFileDescr) {
        if (this.uploadFile) {
            this.upload.emit({ text: inputFileDescr.value, file: this.uploadFile });
            inputFileDescr.value = '';
        }
    }
    onUploading(evt, formRef) {
        this.tooBig = false;
        const el = evt.srcElement || evt.target;
        if (el.files && el.files[0]) {
            this.fileFormRef = evt.target.files[0];
            this.uploadFile = this.fileFormRef;
            this.isImage = this.fileFormRef.type.indexOf('image/') !== -1;
            this.previewTipe = "preview_" + this.fileFormRef.type.split("/")[0];
            const fr = new FileReader();
            if (this.fileFormRef.size < (parseInt(this.context.variables.maxFileSize) * 1024 * 1000 + 500)) { // check file size
                if (this.isImage) { // image preview
                    fr.onload = (e) => {
                        this.dataFile = e.target['result'];
                        formRef.reset();
                        this.cdr.detectChanges();
                    };
                    fr.readAsDataURL(this.fileFormRef);
                }
                else {
                    this.dataFile = true;
                    formRef.reset();
                    this.cdr.detectChanges();
                }
            }
            else {
                this.tooBig = true;
                formRef.reset();
                this.cdr.detectChanges();
            }
        }
    }
    onMultipleUploading(evt, formRef) {
        this.tooBig = false;
        const el = evt.srcElement || evt.target;
        if (el.files && el.files.length) {
            this.fileFormRef = evt.target.files;
            this.uploadFile = this.fileFormRef;
            this.dataFile = true;
        }
    }
};
UploadPanelComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], UploadPanelComponent.prototype, "context", null);
__decorate([
    Output()
], UploadPanelComponent.prototype, "close", void 0);
__decorate([
    Output()
], UploadPanelComponent.prototype, "upload", void 0);
UploadPanelComponent = __decorate([
    Component({
        selector: 'vvc-upload-panel',
        template: "<div class=\"vvc-upload-container\">\n  <label for=\"theFile\" *ngIf=\"!dataFile\">\n    <div class=\"vvc-upload-area\">\n      <svg viewBox=\"0 0 512 512\">\n          <path d=\"M296 384h-80c-13.3 0-24-10.7-24-24V192h-87.7c-17.8 0-26.7-21.5-14.1-34.1L242.3 5.7c7.5-7.5 19.8-7.5 27.3 0l152.2 152.2c12.6 12.6 3.7 34.1-14.1 34.1H320v168c0 13.3-10.7 24-24 24zm216-8v112c0 13.3-10.7 24-24 24H24c-13.3 0-24-10.7-24-24V376c0-13.3 10.7-24 24-24h136v8c0 30.9 25.1 56 56 56h80c30.9 0 56-25.1 56-56v-8h136c13.3 0 24 10.7 24 24zm-124 88c0-11-9-20-20-20s-20 9-20 20 9 20 20 20 20-9 20-20zm64 0c0-11-9-20-20-20s-20 9-20 20 9 20 20 20 20-9 20-20z\"></path>\n       </svg>\n    </div>\n  </label>\n\n  <div class=\"vvc-upload-area\" *ngIf=\"dataFile\">\n    <img [src]=\"dataFile\" *ngIf=\"isImage\">\n    <svg viewBox=\"0 0 384 512\" *ngIf=\"!isImage\" class=\"attachment_preview\" [ngClass]=previewTipe>\n      <path d=\"M224 136V0H24C10.7 0 0 10.7 0 24v464c0 13.3 10.7 24 24 24h336c13.3 0 24-10.7 24-24V160H248c-13.2 0-24-10.8-24-24zm160-14.1v6.1H256V0h6.1c6.4 0 12.5 2.5 17 7l97.9 98c4.5 4.5 7 10.6 7 16.9z\"></path>\n    </svg>\n  </div>\n\n  <div class=\"vvc-upload-loading\" *ngIf=\"_context.isUploading\">\n    <div class=\"inner-loading-panel\">\n      <div class=\"loading-container\">\n        <div class=\"progress-bar\">\n          <div class=\"loaded\"></div>\n        </div>\n      </div>\n    </div>\n  </div>\n\n  <div class=\"too-big\" *ngIf=\"tooBig\">\n    <span> {{ 'STRINGS.UPLOAD.TOO_BIG' | translate:{ maxFileSize: context.variables.maxFileSize } }} </span>\n  </div>\n\n  <div class=\"vvc-upload-description\">\n    <textarea #fileDescr\n              [readonly]=\"_context.isUploading\"\n              [placeholder]=\"'STRINGS.UPLOAD.FILE_DESCRIPTION' | translate\"></textarea>\n    <form id=\"formUploader\" #formUploader enctype=\"multipart/form-data\" onsubmit=\"return false;\">\n      <input *ngIf=\"!context.variables.multiAttachment\" type=\"file\" id=\"theFile\" name=\"theFile\" class=\"input-file\" (change)=\"onUploading($event, formUploader)\">\n      <input *ngIf=\"context.variables.multiAttachment\" type=\"file\" multiple id=\"theFile\" name=\"theFile\" class=\"input-file\" (change)=\"onMultipleUploading($event, formUploader)\">\n    </form>\n  </div>\n  <div class=\"vvc-upload-button-wrap\">\n    <div *ngIf=\"!dataFile\">\n      <label for=\"theFile\" class=\"select-file\">\n\n          {{ 'STRINGS.UPLOAD.SELECT_FILE' | translate }}\n      </label>\n    </div>\n    <div *ngIf=\"dataFile\">\n      <button class=\"upload\"\n              [disabled]=\"_context.isUploading\"\n              (click)=\"doUpload(fileDescr)\">{{ 'STRINGS.UPLOAD.SEND_FILE' | translate }}</button>\n    </div>\n    <div>\n      <button class=\"close\"\n              [disabled]=\"_context.isUploading\"\n              (click)=\"close.emit(); tooBig = false;\">{{ 'STRINGS.UPLOAD.CLOSE_PANEL' | translate }}</button>\n    </div>\n  </div>\n\n  <audio autoplay\n         *ngIf=\"context.voiceRxStream\"\n         [srcObject]=\"context.voiceRxStream\"></audio>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], UploadPanelComponent);

let ChatPanelsModule = class ChatPanelsModule {
};
ChatPanelsModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule
        ],
        exports: [EmojiPanelComponent, UploadPanelComponent],
        declarations: [EmojiPanelComponent, UploadPanelComponent]
    })
], ChatPanelsModule);

let ClosePanelComponent = class ClosePanelComponent {
    constructor() {
        this.cancel = new EventEmitter();
        this.confirm = new EventEmitter();
    }
};
__decorate([
    Output()
], ClosePanelComponent.prototype, "cancel", void 0);
__decorate([
    Output()
], ClosePanelComponent.prototype, "confirm", void 0);
ClosePanelComponent = __decorate([
    Component({
        selector: 'vvc-close-panel',
        template: "<div class=\"inner-close-panel\">\n  <div class=\"close-modal\">\n    <div>{{ 'STRINGS.CLOSEMODAL.CLOSE_MESSAGE' | translate }}</div>\n    <div class=\"buttons-wrapper\">\n      <div><button (click)=\"cancel.emit()\">{{ 'STRINGS.CLOSEMODAL.NO' | translate }}</button></div>\n      <div><button (click)=\"confirm.emit()\">{{ 'STRINGS.CLOSEMODAL.YES' | translate }}</button></div>\n    </div>\n  </div>\n</div>\n\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ClosePanelComponent);

let ClosePanelModule = class ClosePanelModule {
};
ClosePanelModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule
        ],
        exports: [
            ClosePanelComponent
        ],
        declarations: [ClosePanelComponent]
    })
], ClosePanelModule);

let DataCollectionComponent = class DataCollectionComponent {
    constructor() {
        this.submit = new EventEmitter();
        this.showFeedback = false;
    }
    submitData(dc) {
        this.submit.emit({
            dcDefinition: this.context.selectedDataCollection.dc,
            dcData: dc
        });
        if (this.context.selectedDataCollection.type === 'survey')
            this.showFeedback = true;
    }
};
__decorate([
    Input()
], DataCollectionComponent.prototype, "context", void 0);
__decorate([
    Output()
], DataCollectionComponent.prototype, "submit", void 0);
DataCollectionComponent = __decorate([
    Component({
        selector: 'vvc-data-collection',
        template: "<div *ngIf=\"!showFeedback\">\n<vvc-form [dc]=\"context.selectedDataCollection.dc\"\n          [country]=\"context.language\"\n          (submit)=\"submitData($event)\"></vvc-form>\n</div>\n<div *ngIf=\"showFeedback\" [innerHtml]=\"'STRINGS.SURVEY.FEEDBACK' | translate | vvcSanitize:'html' \">\n</div>\n\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], DataCollectionComponent);

function phoneNumberValidator(country) {
    return (control) => {
        if (control.value) {
            const phoneNumber = control.value;
            const phone = parsePhoneNumberFromString(phoneNumber, country.toUpperCase());
            return !phone || (phone && !phone.isValid()) ? { invalidPhoneNumber: { value: control.value } } : null;
        }
        return null;
    };
}

let FormComponent = class FormComponent {
    constructor(fb) {
        this.fb = fb;
        this.fields = [];
        this.hasRequired = false;
        this.readMode = false;
        this.submit = new EventEmitter();
        this.showFeedBack = false;
    }
    ngOnInit() {
        const controllers = {};
        let visibleElements = false;
        this.fields = this.dc.fields.filter(f => f.type !== 'meta' || f.format === 'message');
        for (const idx in this.fields) {
            const elem = this.fields[idx];
            const validators = [];
            const hasDefault = (typeof elem.defaultConstant !== 'undefined') && elem.defaultConstant != null;
            elem.value = (hasDefault && elem.type !== 'boolean') ? elem.defaultConstant.toString() : elem.defaultConstant;
            // elem.value = elem.defaultConstant;
            if ((['visitor', 'both'].indexOf(elem.hidden) === -1 && (!hasDefault || (hasDefault && elem.editIfDefault)))) {
                elem.showElement = true;
                visibleElements = true;
            }
            // validators.push(el.value || '');
            if (elem.required) {
                validators.push(Validators.required);
                this.hasRequired = true;
            }
            if (elem.minLength) {
                if (elem.type === 'string') {
                    validators.push(Validators.minLength(elem.minLength));
                }
                else if (elem.type === 'number') {
                    validators.push(Validators.min(elem.minLength));
                }
            }
            if (elem.maxLength) {
                if (elem.type === 'string') {
                    validators.push(Validators.maxLength(elem.maxLength));
                }
                else if (elem.type === 'number') {
                    validators.push(Validators.max(elem.maxLength));
                }
            }
            if (elem.validation) {
                const validation = (typeof elem.validation === 'boolean') ? elem.validation.toString() : elem.validation;
                validators.push(Validators.pattern(validation));
            }
            if (elem.format === 'phonenum' && !elem.validation) {
                if (this.country) {
                    validators.push(phoneNumberValidator(this.country));
                }
                else {
                    validators.push(Validators.pattern('^\\s*\\+\\s*(?:\\d\\s*){7,}$'));
                }
            }
            if (elem.format === 'email') {
                validators.push(Validators.email);
            }
            if (elem.format === 'rating') {
                elem.ratings = [];
                for (let i = elem.max || 1; i >= (elem.min || 1); i--) {
                    elem.ratings.push(i);
                }
            }
            controllers[elem.id] = [(this.dc.dataValue && this.dc.dataValue[elem.id]) || elem.value || '', validators];
        }
        this.form = this.fb.group(controllers);
        if (!visibleElements) {
            this.onSubmit(new Event('submit'));
        }
    }
    getForm() {
        return this.form;
    }
    getInputElement(elem) {
        let element;
        switch (elem.format) {
            case 'dropdown':
                element = 'select';
                break;
            case 'checkbox':
            case 'radio':
            case 'rating':
            case 'textarea':
            case 'message':
                element = elem.format;
                break;
            default:
                element = 'input';
                break;
        }
        return element;
    }
    getInputType(elem) {
        if (['text', 'email', 'date', 'time'].indexOf(elem.format) !== -1) {
            return elem.format;
        }
        else if (elem.format === 'phonenum') {
            return 'text';
        }
        else if (elem.format === 'link') {
            return 'url';
        }
        else if (elem.format === 'date-time') {
            return 'datetime-local';
        }
        else {
            return elem.type;
        }
    }
    onSubmit(event) {
        event.stopPropagation();
        this.submit.emit(this.form.value);
    }
    optionsKeys(elem) {
        return Object.keys(elem);
    }
};
FormComponent.ctorParameters = () => [
    { type: FormBuilder }
];
__decorate([
    Input()
], FormComponent.prototype, "dc", void 0);
__decorate([
    Input()
], FormComponent.prototype, "country", void 0);
__decorate([
    Input()
], FormComponent.prototype, "readMode", void 0);
__decorate([
    Output()
], FormComponent.prototype, "submit", void 0);
FormComponent = __decorate([
    Component({
        selector: 'vvc-form',
        template: "<div class=\"vvc-form\">\n  <div class=\"form-required-legend\" *ngIf=\"hasRequired\">{{ 'STRINGS.DC.REQUIRED_LEGEND' | translate }}</div>\n  <form [formGroup]=\"form\" (ngSubmit)=\"onSubmit($event)\">\n    <div *ngFor=\"let elem of fields\">\n      <div class=\"vvc-input\"\n           *ngIf=\"elem.showElement\"\n           [ngClass]=\"{'error' : form.get(elem.id) && form.get(elem.id).errors && form.get(elem.id).touched, 'vvc-checkbox': getInputElement(elem) === 'checkbox'}\">\n\n        <label *ngIf=\"elem.format !== 'message'\">{{ (elem.labelId | translate) || elem.id }}<span *ngIf=\"elem.required\" class=\"required\"> *</span></label>\n\n        <!-- message -->\n        <div  class=\"message\" *ngIf=\"getInputElement(elem) === 'message'\" [innerHTML]=\"elem.message | translate | vvcSanitize:'html' \"></div>\n\n        <!-- text -->\n        <input *ngIf=\"!readMode && getInputElement(elem) === 'input'\"\n               [formControlName]=\"elem.id\"\n               type=\"{{ getInputType(elem) }}\"\n               placeholder=\"{{ elem.placeholderId | translate }}\" />\n\n        <!-- textarea -->\n        <textarea *ngIf=\"!readMode && getInputElement(elem) === 'textarea'\"\n                  [formControlName]=\"elem.id\"\n                  placeholder=\"{{ elem.placeholderId | translate }}\"></textarea>\n\n        <!-- dropdown -->\n        <select *ngIf=\"!readMode && getInputElement(elem) === 'select'\"\n                [formControlName]=\"elem.id\">\n          <option value=\"\" selected></option>\n          <option *ngFor=\"let key of optionsKeys(elem.options)\" [value]=\"key\">{{elem.options[key] | translate}}</option>\n        </select>\n\n        <!-- checkbox -->\n        <input *ngIf=\"!readMode && getInputElement(elem) === 'checkbox'\"\n               [formControlName]=\"elem.id\"\n               type=\"checkbox\" />\n\n        <!-- radio -->\n        <div *ngIf=\"!readMode && getInputElement(elem) === 'radio'\">\n          <div *ngFor=\"let key of optionsKeys(elem.options)\">\n            <input [formControlName]=\"elem.id\"\n                   [value]=\"key\"\n                   [id]=\"key\"\n                   type=\"radio\" />\n            <label [for]=\"key\">{{ elem.options[key] | translate }}</label>\n          </div>\n        </div>\n\n        <!-- rating -->\n        <div *ngIf=\"!readMode && getInputElement(elem) === 'rating'\">\n          <div>{{ elem.name | translate }}</div>\n          <div class=\"vvc-bar-rating {{'vvc-bar-rating-'+elem.style}}\">\n            <ng-container *ngFor=\"let i of elem.ratings\">\n              <input type=\"radio\" id=\"{{elem.id}}{{i}}\" [formControlName]=\"elem.id\" [value]=\"i.toString()\" />\n              <label for=\"{{elem.id}}{{i}}\"></label>\n            </ng-container>\n          </div>\n        </div>\n\n        <div *ngIf=\"readMode\">\n          {{ dc.dataValue[elem.id] || '-' }}\n        </div>\n\n        <p *ngIf=\"form.get(elem.id) && form.get(elem.id).touched && !readMode\">\n          <span *ngIf=\"form.get(elem.id).hasError('required')\">{{ 'STRINGS.DC.REQUIRED_ERR' | translate }}</span>\n          <span *ngIf=\"form.get(elem.id).hasError('email')\">{{ 'STRINGS.DC.EMAIL_ERR' | translate }}</span>\n        </p>\n      </div>\n    </div>\n    <div *ngIf=\"!readMode\">\n      <button class=\"btn-primary\"\n              [disabled]=\"form.invalid\">{{ 'STRINGS.NEXT_BUTTON' | translate }}</button>\n    </div>\n  </form>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], FormComponent);

let DataCollectionModule = class DataCollectionModule {
};
DataCollectionModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            ReactiveFormsModule,
            VvcCommonModule
        ],
        exports: [
            DataCollectionComponent
        ],
        declarations: [
            DataCollectionComponent,
            FormComponent
        ]
    })
], DataCollectionModule);

let LoadingPanelComponent = class LoadingPanelComponent {
};
LoadingPanelComponent = __decorate([
    Component({
        selector: 'vvc-loading-panel',
        template: "<div class=\"loading-view\">\n  <!--\n  <div  *ngIf=\"context.translationLoaded\"\n        class=\"loading-message animated fadeInUp\"\n        [innerHtml]=\" 'STRINGS.LOADING' | translate \"></div>\n  <div class=\"loading-loading animated fadeInUp\">\n    <div class=\"inner-loading-panel\">\n      <div class=\"loading-container\">\n        <div class=\"progress-bar\">\n          <div class=\"loaded\"></div>\n        </div>\n      </div>\n    </div>\n  </div>\n  -->\n</div>\n\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], LoadingPanelComponent);

let LoadingPanelModule = class LoadingPanelModule {
};
LoadingPanelModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule
        ],
        exports: [
            LoadingPanelComponent
        ],
        declarations: [LoadingPanelComponent]
    })
], LoadingPanelModule);

let ChatMessageComponent = class ChatMessageComponent {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.showDoc = new EventEmitter();
        this.read = new EventEmitter();
        this.resend = new EventEmitter();
        this.isFirst = false;
        this.isLast = false;
        this.markReadHandler = this.markRead.bind(this);
    }
    onClick(event) {
        event.preventDefault();
        if (event.target.href) {
            this.openDocument(event.target.href);
        }
    }
    markRead() {
        this.read.emit(this.message.id);
    }
    ngOnInit() {
        this.isFirst = this.disableMessageGrouping ? true : this.message.isFirst;
        this.isLast = this.disableMessageGrouping ? true : this.message.isLast;
        if (this.message.meta && this.message.meta.mimetype) {
            this.previewTipe = 'preview_' + this.message.meta.mimetype.split("/")[0];
        }
        this.msgElement = this.chatMsg.nativeElement;
        this.listElement = this.chatMsg.nativeElement.closest('#vvc-messages');
        const doCheckForRead = this.message && (this.message.type === 'chat') && this.message.isAgent && !this.message.delivered && !this.message.read;
        if (doCheckForRead) {
            setTimeout(() => {
                if (this.isInView()) {
                    this.markRead();
                }
                else {
                    this.addScrollListener();
                }
            }, 200);
        }
    }
    isInView() {
        const partial = true;
        const contHeight = this.listElement.scrollHeight;
        const contTop = this.listElement.scrollTop;
        const contBottom = contTop + contHeight;
        const elemTop = this.msgElement.offsetTop - this.listElement.offsetTop;
        const elemBottom = elemTop + this.msgElement.scrollHeight;
        const isTotal = (elemTop >= 0 && elemBottom <= contHeight);
        const isPart = ((elemTop < 0 && elemBottom > 0) || (elemTop > 0 && elemTop <= contHeight)) && partial;
        return isTotal || isPart;
    }
    addScrollListener() {
        this.listElement.addEventListener('scroll', this.markReadHandler);
    }
    checkForRead() {
        if (this.isInView()) {
            this.listElement.removeEventListener('scroll', this.markReadHandler);
            this.markRead();
        }
    }
    openDocument(url) {
        this.showDoc.emit(url);
    }
    sendFailed() {
        this.resend.emit(this.message);
    }
    sanitizeThis(url) {
        return this.sanitizer.bypassSecurityTrustStyle(`url(${url})`);
    }
};
ChatMessageComponent.ctorParameters = () => [
    { type: DomSanitizer }
];
__decorate([
    Input()
], ChatMessageComponent.prototype, "message", void 0);
__decorate([
    Input()
], ChatMessageComponent.prototype, "disableMessageGrouping", void 0);
__decorate([
    Output()
], ChatMessageComponent.prototype, "showDoc", void 0);
__decorate([
    Output()
], ChatMessageComponent.prototype, "read", void 0);
__decorate([
    Output()
], ChatMessageComponent.prototype, "resend", void 0);
__decorate([
    HostListener('click', ['$event'])
], ChatMessageComponent.prototype, "onClick", null);
__decorate([
    ViewChild('chatMsg', { static: true })
], ChatMessageComponent.prototype, "chatMsg", void 0);
ChatMessageComponent = __decorate([
    Component({
        selector: 'vvc-chat-message',
        template: "<div #chatMsg class=\"chat-message\" [ngClass]=\"{ 'agent': message.isAgent, 'visitor': !message.isAgent, 'bot': message.isAgent && message.agent.is_bot, 'real_agent': message.isAgent && !message.agent.is_bot }\">\n  <div class=\"message-spacer\" *ngIf=\"!message.isAgent\"></div>\n  <div class=\"message-avatar\" *ngIf=\"message.isAgent && (message.avatar || message.agent && message.agent.avatar)\" [style.visibility]=\"isFirst ? 'visible' : 'hidden'\">\n    <img [src]=\"message.avatar || message.agent.avatar\">\n  </div>\n  <div class=\"message\"\n       [ngClass]=\"{ 'arrow' : isFirst }\">\n    <div *ngIf=\"!message.meta && (!message.isAgent || (message.isAgent && !message.agent.is_bot))\"\n          class=\"bubble\"\n          [innerHTML]=\"message.text | vvcLink:{sanitizeHtml: true}\"></div>\n    <div *ngIf=\"!message.meta && message.isAgent && message.agent.is_bot\"\n          class=\"bubble\"\n          [innerHTML]=\"message.text | vvcLink\"></div>\n    <div *ngIf=\"message.meta\" class=\"bubble attachment\" (click)=\"openDocument(message.meta.url)\">\n      <div class=\"attachment-img\" *ngIf=\"message.meta.mimetype.indexOf('image/') !== -1\">\n        <img [src]=\"message.meta.url\">\n      </div>\n      <div class=\"attachment-img\" *ngIf=\"message.meta.mimetype.indexOf('image/') === -1\">\n        <svg viewBox=\"0 0 384 512\" [ngClass]=\"previewTipe\">\n          <path d=\"M224 136V0H24C10.7 0 0 10.7 0 24v464c0 13.3 10.7 24 24 24h336c13.3 0 24-10.7 24-24V160H248c-13.2 0-24-10.8-24-24zm160-14.1v6.1H256V0h6.1c6.4 0 12.5 2.5 17 7l97.9 98c4.5 4.5 7 10.6 7 16.9z\"></path>\n        </svg>\n      </div>\n      <div class=\"attachment-text\">\n        {{ message.text || message.meta.desc}}\n      </div>\n    </div>\n    <div class=\"time\" *ngIf=\"isLast\">\n      <span class=\"msg-warnings\" *ngIf=\"message.failed\" (click)=\"sendFailed()\">\n        <svg height=\"12\" viewBox=\"0 0 12 12\" width=\"12\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-438 -224)\"><path d=\"m0 0h908v900h-908z\" fill=\"#fff\"/><path d=\"m5.77639233 1.67083605c.22934693-.11467403.50469266-.03654433.64173472.17295535l.02908611.05065013 4.19100574 8.38197037c.0347141.069428.0527868.1459848.0527868.2236077 0 .2564179-.1930201.4677536-.4416894.4966361l-.0583106.0033639h-8.38201143c-.07762288 0-.15417973-.0180727-.22360768-.0527868-.22934693-.1146741-.33204956-.3818289-.24667413-.617162l.02306865-.0536589 4.19100573-8.38197037c.04838174-.09676301.12684248-.17522374.22360549-.22360548zm.22360767 1.57916395-3.5 6.7500196h7zm0 5.25c.27614238 0 .5.22385762.5.5 0 .27614237-.22385762.5-.5.5-.27614237 0-.5-.22385763-.5-.5 0-.27614238.22385763-.5.5-.5zm0-3.5c.27614238 0 .5.22385762.5.5v2c0 .27614237-.22385762.5-.5.5-.27614237 0-.5-.22385763-.5-.5v-2c0-.27614238.22385763-.5.5-.5z\" fill=\"#e55e3b\" fill-rule=\"nonzero\" transform=\"translate(438 224)\"/></g></svg>\n      </span>\n      <span class=\"msg-warnings\" *ngIf=\"message.ackIsLate1 && !message.ackIsLate2\">\n        <svg height=\"12\" viewBox=\"0 0 12 12\" width=\"12\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\"><path d=\"m-438-276h908v900h-908z\" fill=\"#fff\"/><g><path d=\"m0 0h12v12h-12z\"/><path d=\"m6 3c.92906869 0 1.78415734.31674622 2.46316895.84814168l.70104461-.70169507.70710678.70710678-.70323055.70415931c.52160767.67562246.83191021 1.52271736.83191021 2.4422873 0 2.209139-1.790861 4-4 4s-4-1.790861-4-4 1.790861-4 4-4zm0 1c-1.65685425 0-3 1.34314575-3 3s1.34314575 3 3 3 3-1.34314575 3-3-1.34314575-3-3-3zm0 1 .08774863.00815092c.2289952.04283657.41225137.24939903.41225137.49776138v1.4881754c0 .27519941-.22385763.5059123-.5.5059123-.26806641 0-.5-.22650465-.5-.5059123v-1.4881754c0-.27519941.22385763-.5059123.5-.5059123zm2-4v1h-4v-1z\" fill=\"#949ea8\"/></g></g></svg>\n      </span>\n      <span class=\"msg-warnings\" *ngIf=\"message.ackIsLate2\">\n        <svg height=\"12\" viewBox=\"0 0 12 12\" width=\"12\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-438 -250)\"><path d=\"m0 0h908v900h-908z\" fill=\"#fff\"/><path d=\"m5.77639233 1.67083605c.22934693-.11467403.50469266-.03654433.64173472.17295535l.02908611.05065013 4.19100574 8.38197037c.0347141.069428.0527868.1459848.0527868.2236077 0 .2564179-.1930201.4677536-.4416894.4966361l-.0583106.0033639h-8.38201143c-.07762288 0-.15417973-.0180727-.22360768-.0527868-.22934693-.1146741-.33204956-.3818289-.24667413-.617162l.02306865-.0536589 4.19100573-8.38197037c.04838174-.09676301.12684248-.17522374.22360549-.22360548zm.22360767 1.57916395-3.5 6.7500196h7zm0 5.25c.27614238 0 .5.22385762.5.5 0 .27614237-.22385762.5-.5.5-.27614237 0-.5-.22385763-.5-.5 0-.27614238.22385763-.5.5-.5zm0-3.5c.27614238 0 .5.22385762.5.5v2c0 .27614237-.22385762.5-.5.5-.27614237 0-.5-.22385763-.5-.5v-2c0-.27614238.22385763-.5.5-.5z\" fill=\"#f5b83a\" fill-rule=\"nonzero\" transform=\"translate(438 250)\"/></g></svg>\n      </span>\n      <span class=\"msg-acks\" *ngIf=\"!message.failed && !message.ackIsLate1 && !message.ackIsLate2\">\n        <span title=\"{{ 'STRINGS.TOOLTIP.MSG_SENT' | translate }}\" *ngIf=\"!message.isAgent && !message.ack\"><svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m8.53240548.28116753c.29849321-.33630114.82445569-.37663004 1.17477007-.09007713.31139055.25471371.37918205.68196672.18076123 1.00996226l-.0869307.11781478-5.68048261 6.39998731c-.29253479.32958801-.79514582.36995316-1.13883325.11815649l-.12071254-.10812458-2.65285073-2.89031685c-.30426455-.33150035-.27098776-.83702296.0743258-1.12911635.30694538-.25963857.75711923-.26324628 1.06706313-.02801929l.10910206.09937191 2.01642117 2.19680114z\" fill=\"#666\" fill-rule=\"evenodd\" transform=\"translate(6 4)\"/></svg></span>\n        <span title=\"{{ 'STRINGS.TOOLTIP.MSG_RECEIVED' | translate:message.tooltipData}}\" *ngIf=\"!message.isAgent && message.ack && !message.read\"><svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\"><path d=\"m0 0h16v16h-16z\"/><g fill=\"#666\" transform=\"translate(1 4)\"><path d=\"m8.53240548.28116753c.29849321-.33630114.82445569-.37663004 1.17477007-.09007713.31139055.25471371.37918205.68196672.18076123 1.00996226l-.0869307.11781478-5.68048261 6.39998731c-.29253479.32958801-.79514582.36995316-1.13883325.11815649l-.12071254-.10812458-2.65285073-2.89031685c-.30426455-.33150035-.27098776-.83702296.0743258-1.12911635.30694538-.25963857.75711923-.26324628 1.06706313-.02801929l.10910206.09937191 2.01642117 2.19680114z\"/><path d=\"m14.7071756.1910904c.3113905.25471371.379182.68196672.1807612 1.00996226l-.0869307.11781478-5.68048263 6.39998731c-.29253479.32958801-.79514582.36995316-1.13883325.11815649l-.12071254-.10812458-1.22694885-1.3368832 1.093-1.23.74801028.81560376 5.05736639-5.69643969c.2984932-.33630114.8244557-.37663004 1.1747701-.09007713zm-8.35765972 3.49034377.10910206.09937191.58841089.64019738-1.092 1.231-.74690188-.81343365c-.15213227-.16575018-.21987921-.37500592-.20642889-.57933579l.64552638-.7294867c.24154924-.05291416.50138138-.00079065.70229144.15168685z\"/></g></g></svg></span>\n        <span title=\"{{ 'STRINGS.TOOLTIP.MSG_READ' | translate:message.tooltipData}}\" *ngIf=\"!message.isAgent && message.ack && message.read\"><svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\"><defs><path id=\"a-msg-acks-read\" d=\"m8.53240548.28116753c.29849321-.33630114.82445569-.37663004 1.17477007-.09007713.31139055.25471371.37918205.68196672.18076123 1.00996226l-.0869307.11781478-5.68048261 6.39998731c-.29253479.32958801-.79514582.36995316-1.13883325.11815649l-.12071254-.10812458-2.65285073-2.89031685c-.30426455-.33150035-.27098776-.83702296.0743258-1.12911635.30694538-.25963857.75711923-.26324628 1.06706313-.02801929l.10910206.09937191 2.01642117 2.19680114z\"/></defs><g fill=\"none\" fill-rule=\"evenodd\"><path d=\"m0 0h16v16h-16z\"/><g transform=\"translate(1 4)\"><path d=\"m14.7071756.1910904c.3113905.25471371.379182.68196672.1807612 1.00996226l-.0869307.11781478-5.68048263 6.39998731c-.29253479.32958801-.79514582.36995316-1.13883325.11815649l-.12071254-.10812458-1.22694885-1.3368832 1.093-1.23.74801028.81560376 5.05736639-5.69643969c.2984932-.33630114.8244557-.37663004 1.1747701-.09007713zm-8.35765972 3.49034377.10910206.09937191.58841089.64019738-1.092 1.231-.74690188-.81343365c-.15213227-.16575018-.21987921-.37500592-.20642889-.57933579l.64552638-.7294867c.24154924-.05291416.50138138-.00079065.70229144.15168685z\" fill=\"#5f9f18\"/><use fill=\"#f3f3f3\" xlink:href=\"#a-msg-acks-read\"/><use fill=\"#5f9f18\" xlink:href=\"#a-msg-acks-read\"/></g></g></svg></span>\n      </span>\n       {{ message.time }}\n    </div>\n  </div>\n  <div class=\"message-avatar\" *ngIf=\"!message.isAgent\" [style.visibility]=\"isFirst ? 'visible' : 'hidden'\">\n    <div class=\"message-visitor\"></div>\n  </div>\n  <div class=\"message-spacer\" *ngIf=\"message.isAgent\"></div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], ChatMessageComponent);

let SystemMessageComponent = class SystemMessageComponent {
};
__decorate([
    Input()
], SystemMessageComponent.prototype, "message", void 0);
SystemMessageComponent = __decorate([
    Component({
        selector: 'vvc-system-message',
        template: "<div class=\"system-message\" [innerHtml]=\" message.text | translate:message.context | vvcSanitize:'html' \"></div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], SystemMessageComponent);

let TemplateGenericComponent = class TemplateGenericComponent {
    constructor() {
        this.action = new EventEmitter();
        this.scrollUpdate = new EventEmitter();
        this.read = new EventEmitter();
        this.scrollOffset = 0;
        this.lastCarouselElem = 0;
        this.transition = 'none';
        this.carouselElemWith = 260;
        this.markReadHandler = this.markRead.bind(this);
    }
    markRead() {
        this.read.emit(this.message.id);
    }
    ngOnInit() {
        if (this.message) {
            this.scrollOffset = this.message.scrollLeft;
            this.transition = 'smooth';
            if (this.message.elements.length > 1) {
                this.lastCarouselElem = ((this.message.elements.length - 1) * this.carouselElemWith) - 1;
            }
        }
        this.msgElement = this.tplGen.nativeElement;
        this.listElement = this.tplGen.nativeElement.closest('#vvc-messages');
        const doCheckForRead = this.message && this.message.agent && !this.message.delivered && !this.message.read;
        if (doCheckForRead) {
            setTimeout(() => {
                if (this.isInView()) {
                    this.markRead();
                }
                else {
                    this.addScrollListener();
                }
            }, 200);
        }
    }
    isInView() {
        const partial = true;
        const contHeight = this.listElement.scrollHeight;
        const contTop = this.listElement.scrollTop;
        const contBottom = contTop + contHeight;
        const elemTop = this.msgElement.offsetTop - this.listElement.offsetTop;
        const elemBottom = elemTop + this.msgElement.scrollHeight;
        const isTotal = (elemTop >= 0 && elemBottom <= contHeight);
        const isPart = ((elemTop < 0 && elemBottom > 0) || (elemTop > 0 && elemTop <= contHeight)) && partial;
        return isTotal || isPart;
    }
    addScrollListener() {
        this.listElement.addEventListener('scroll', this.markReadHandler);
    }
    checkForRead() {
        if (this.isInView()) {
            this.listElement.removeEventListener('scroll', this.markReadHandler);
            this.markRead();
        }
    }
    ngOnDestroy() {
        if (this.scrollOffset !== this.message.scrollLeft) {
            this.scrollUpdate.emit({ scrollLeft: this.scrollOffset, messageId: this.message.id });
        }
    }
    scrollRight() {
        this.scrollOffset = this.scrollOffset + this.carouselElemWith;
    }
    scrollLeft() {
        this.scrollOffset = this.scrollOffset - this.carouselElemWith;
    }
    defaultAction(elem) {
        if (elem.default_action) {
            this.action.emit(elem.default_action);
        }
    }
    swipe(ev) {
        if (ev === "swiperight") {
            if (this.message.elements.length > 1 && this.scrollOffset > 0) {
                this.scrollLeft();
            }
        }
        if (ev === "swipeleft") {
            if (this.message.elements.length > 1 && this.scrollOffset <= this.lastCarouselElem) {
                this.scrollRight();
            }
        }
    }
};
__decorate([
    Input()
], TemplateGenericComponent.prototype, "message", void 0);
__decorate([
    Output()
], TemplateGenericComponent.prototype, "action", void 0);
__decorate([
    Output()
], TemplateGenericComponent.prototype, "scrollUpdate", void 0);
__decorate([
    Output()
], TemplateGenericComponent.prototype, "read", void 0);
__decorate([
    ViewChild('carousel', { static: true })
], TemplateGenericComponent.prototype, "container", void 0);
__decorate([
    ViewChild('tplGen', { static: true })
], TemplateGenericComponent.prototype, "tplGen", void 0);
TemplateGenericComponent = __decorate([
    Component({
        selector: 'vvc-template-generic',
        template: "<div #tplGen class=\"tpl-navigation\">\n\n  <div class=\"tpl-left\" *ngIf=\"message.elements.length > 1 && scrollOffset > 0\" (click)=\"scrollLeft()\"></div>\n\n  <div class=\"tpl-right\" *ngIf=\"message.elements.length > 1 && scrollOffset <= lastCarouselElem\" (click)=\"scrollRight()\"></div>\n\n  <div #carousel\n       class=\"tpl-container\"\n       [scrollLeft]=\"scrollOffset || 0\"\n       [style.scroll-behavior]=\"transition\"\n       [ngClass]=\"{'carousel' : (message.elements.length > 1) }\"\n       (swipeleft)=\"swipe($event.type)\" \n       (swiperight)=\"swipe($event.type)\">\n\n    <div *ngFor=\"let elem of message.elements\" class=\"tpl-element\" [ngClass]=\"{'carousel' : (message.elements.length > 1) }\">\n      <div class=\"vvc-template-inner\">\n        <div *ngIf=\"elem.image_url\" class=\"cover\" [style.background-image]=\"'url(' + elem.image_url + ')'\"></div>\n        <div class=\"title\"\n             [ngClass]=\"{'tpl-has-default':elem.default_action}\"\n             (click)=\"defaultAction(elem)\">{{ elem.title }}</div>\n        <div class=\"subtitle\">{{ elem.subtitle }}</div>\n      </div>\n      <div class=\"vvc-template-action\" *ngFor=\"let btn of elem.buttons\">\n        <button (click)=\"action.emit(btn)\">{{ btn.title }}</button>\n      </div>\n    </div>\n  </div>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], TemplateGenericComponent);

let QuickRepliesComponent = class QuickRepliesComponent {
    constructor() {
        this.action = new EventEmitter();
        this.scrollUpdate = new EventEmitter();
        this.read = new EventEmitter();
        this.hasReplied = false;
        this.scrollOffset = 0;
        this.transition = 'none';
        this.markReadHandler = this.markRead.bind(this);
    }
    markRead() {
        this.read.emit(this.message.id);
    }
    ngOnInit() {
        if (this.message) {
            this.castedMessage = Object.assign({}, this.message, { text: this.message.body, isAgent: true });
            this.scrollOffset = this.message.scrollLeft;
            this.transition = 'smooth';
        }
        this.msgElement = this.qrMsg.nativeElement;
        this.listElement = this.qrMsg.nativeElement.closest('#vvc-messages');
        const doCheckForRead = this.message && this.message.agent && !this.message.delivered && !this.message.read;
        if (doCheckForRead) {
            setTimeout(() => {
                if (this.isInView()) {
                    this.markRead();
                }
                else {
                    this.addScrollListener();
                }
            }, 200);
        }
    }
    isInView() {
        const partial = true;
        const contHeight = this.listElement.scrollHeight;
        const contTop = this.listElement.scrollTop;
        const contBottom = contTop + contHeight;
        const elemTop = this.msgElement.offsetTop - this.listElement.offsetTop;
        const elemBottom = elemTop + this.msgElement.scrollHeight;
        const isTotal = (elemTop >= 0 && elemBottom <= contHeight);
        const isPart = ((elemTop < 0 && elemBottom > 0) || (elemTop > 0 && elemTop <= contHeight)) && partial;
        return isTotal || isPart;
    }
    addScrollListener() {
        this.listElement.addEventListener('scroll', this.markReadHandler);
    }
    checkForRead() {
        if (this.isInView()) {
            this.listElement.removeEventListener('scroll', this.markReadHandler);
            this.markRead();
        }
    }
    ngOnDestroy() {
        if (this.scrollOffset !== this.message.scrollLeft) {
            this.scrollUpdate.emit({ scrollLeft: this.scrollOffset, messageId: this.message.id });
        }
    }
    btnClicked(btn) {
        this.action.emit({ action: btn, msgId: this.message.id });
    }
    hasImage() {
        let img = false;
        if (this.message && this.message.quick_replies) {
            this.message.quick_replies.forEach(m => {
                if (m.image_url) {
                    img = true;
                }
            });
        }
        return img;
    }
    showCentered() {
        return (this.message && this.message.quick_replies.length === 2);
    }
    showScrollers() {
        return (this.message && this.message.quick_replies.length > 2);
    }
    scrollRight() {
        this.scrollOffset = this.scrollOffset + 200;
    }
    scrollLeft() {
        this.scrollOffset = this.scrollOffset - 200;
    }
    canShowButtons() {
        if (this.message && this.message.no_quick_replies_interaction && this.noInteractionMode === 'remove_buttons')
            return false;
        return !this.message.replied;
    }
};
__decorate([
    Input()
], QuickRepliesComponent.prototype, "message", void 0);
__decorate([
    Input()
], QuickRepliesComponent.prototype, "showQuickRepliesAsBalloon", void 0);
__decorate([
    Input()
], QuickRepliesComponent.prototype, "noInteractionMode", void 0);
__decorate([
    Input()
], QuickRepliesComponent.prototype, "hideQuickRepliesBodyWhenEmpty", void 0);
__decorate([
    Output()
], QuickRepliesComponent.prototype, "action", void 0);
__decorate([
    Output()
], QuickRepliesComponent.prototype, "scrollUpdate", void 0);
__decorate([
    Output()
], QuickRepliesComponent.prototype, "read", void 0);
__decorate([
    ViewChild('qrContainer', { static: true })
], QuickRepliesComponent.prototype, "container", void 0);
__decorate([
    ViewChild('qrMsg', { static: true })
], QuickRepliesComponent.prototype, "qrMsg", void 0);
QuickRepliesComponent = __decorate([
    Component({
        selector: 'vvc-quick-replies',
        template: "<div #qrMsg class=\"vvc-quick-replies\" [ngClass]=\"{'horizontal': message.quick_replies_orientation !== 'vertical', 'vertical': message.quick_replies_orientation === 'vertical'}\">\n  <div *ngIf=\"!(hideQuickRepliesBodyWhenEmpty && !message.body)\">\n      <div *ngIf=\"!showQuickRepliesAsBalloon\" class=\"reply-message\">{{ message.body }}</div>\n      <div *ngIf=\"showQuickRepliesAsBalloon\" class=\"reply-message-balloon\">\n          <vvc-chat-message [message]=\"castedMessage\"></vvc-chat-message>\n      </div>\n  </div>\n  <div #qrContainer class=\"qr-buttons\"\n       [scrollLeft]=\"scrollOffset || 0\"\n       [style.scroll-behavior]=\"transition\"\n       [ngClass]=\"{'centered':showCentered()}\"\n                    *ngIf=\"canShowButtons()\">\n    <div class=\"tpl-left\"\n         [ngClass]=\"{'hasImg': hasImage()}\"\n         *ngIf=\"showScrollers()\" (click)=\"scrollLeft()\"></div>\n\n    <div class=\"tpl-right\"\n         [ngClass]=\"{'hasImg': hasImage()}\"\n         *ngIf=\"showScrollers()\" (click)=\"scrollRight()\"></div>\n\n    <div class=\"reply\" *ngFor=\"let btn of message.quick_replies\" [ngClass]=\"{ 'img': btn.image_url }\">\n      <button [disabled]=\"message.no_quick_replies_interaction && noInteractionMode === 'disable_buttons'\" (click)=\"btnClicked(btn)\">\n        <img *ngIf=\"btn.image_url\" [src]=\"btn.image_url\"> {{ btn.title }}\n      </button>\n    </div>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], QuickRepliesComponent);

let TemplateListComponent = class TemplateListComponent {
    constructor() {
        this.action = new EventEmitter();
        this.read = new EventEmitter();
        this.markReadHandler = this.markRead.bind(this);
    }
    markRead() {
        this.read.emit(this.message.id);
    }
    ngOnInit() {
        this.msgElement = this.tplList.nativeElement;
        this.listElement = this.tplList.nativeElement.closest('#vvc-messages');
        const doCheckForRead = this.message && this.message.agent && !this.message.delivered && !this.message.read;
        if (doCheckForRead) {
            setTimeout(() => {
                if (this.isInView()) {
                    this.markRead();
                }
                else {
                    this.addScrollListener();
                }
            }, 200);
        }
    }
    isInView() {
        const partial = true;
        const contHeight = this.listElement.scrollHeight;
        const contTop = this.listElement.scrollTop;
        const contBottom = contTop + contHeight;
        const elemTop = this.msgElement.offsetTop - this.listElement.offsetTop;
        const elemBottom = elemTop + this.msgElement.scrollHeight;
        const isTotal = (elemTop >= 0 && elemBottom <= contHeight);
        const isPart = ((elemTop < 0 && elemBottom > 0) || (elemTop > 0 && elemTop <= contHeight)) && partial;
        return isTotal || isPart;
    }
    addScrollListener() {
        this.listElement.addEventListener('scroll', this.markReadHandler);
    }
    checkForRead() {
        if (this.isInView()) {
            this.listElement.removeEventListener('scroll', this.markReadHandler);
            this.markRead();
        }
    }
    defaultAction(elem) {
        if (elem.default_action)
            this.action.emit(elem.default_action);
    }
};
__decorate([
    Input()
], TemplateListComponent.prototype, "message", void 0);
__decorate([
    Output()
], TemplateListComponent.prototype, "action", void 0);
__decorate([
    Output()
], TemplateListComponent.prototype, "read", void 0);
__decorate([
    ViewChild('tplList', { static: true })
], TemplateListComponent.prototype, "tplList", void 0);
TemplateListComponent = __decorate([
    Component({
        selector: 'vvc-template-list',
        template: "<div #tplList class=\"tpl-list-container\">\n  <div *ngFor=\"let elem of message.elements\" class=\"tpl-element\" [ngClass]=\"{'tpl-has-action':message.buttons}\">\n    <div class=\"vvc-template-inner\">\n      <div class=\"title\"\n           [ngClass]=\"{'tpl-has-default':elem.default_action}\"\n           (click)=\"defaultAction(elem)\">{{ elem.title }}</div>\n      <div class=\"subtitle\">{{ elem.subtitle }}</div>\n      <div class=\"action\">\n        <span *ngFor=\"let b of elem.buttons\"\n                (click)=\"action.emit(b)\">{{b.title}}</span>\n      </div>\n    </div>\n  </div>\n</div>\n<div class=\"tpl-list-action\" *ngFor=\"let btn of message.buttons\">\n  <button (click)=\"action.emit(btn)\">{{ btn.title }}</button>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], TemplateListComponent);

let RequestMessageComponent = class RequestMessageComponent {
    constructor() {
        this.accept = new EventEmitter();
        this.reject = new EventEmitter();
    }
};
__decorate([
    Input()
], RequestMessageComponent.prototype, "message", void 0);
__decorate([
    Output()
], RequestMessageComponent.prototype, "accept", void 0);
__decorate([
    Output()
], RequestMessageComponent.prototype, "reject", void 0);
RequestMessageComponent = __decorate([
    Component({
        selector: 'vvc-request-message',
        template: "<div class=\"request-message-wrap\">\n  <div class=\"request-message\" [innerHtml]=\" 'STRINGS.MESSAGES.' + message.text | translate | vvcSanitize:'html' \"></div>\n  <div class=\"request-buttons\">\n    <div class=\"btn\">\n      <button (click)=\"accept.emit(message.text)\">{{ 'STRINGS.MESSAGES.REQUEST_ACCEPT' | translate }}</button>\n    </div>\n    <div class=\"btn\">\n      <button (click)=\"reject.emit(message.text)\">{{ 'STRINGS.MESSAGES.REQUEST_REJECT' | translate }}</button>\n    </div>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], RequestMessageComponent);

let LinkMessageComponent = class LinkMessageComponent {
    constructor() {
        this.linkClicked = new EventEmitter();
    }
};
__decorate([
    Input()
], LinkMessageComponent.prototype, "message", void 0);
__decorate([
    Output()
], LinkMessageComponent.prototype, "linkClicked", void 0);
LinkMessageComponent = __decorate([
    Component({
        selector: 'vvc-link-message',
        template: "<div class=\"system-message message-link\"\n     [innerHtml]=\"'STRINGS.LINK_PUSH' | translate:{ link: message.text }\"\n     [title]=\"message.url\"\n     (click)=\"linkClicked.emit(message.url)\"></div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], LinkMessageComponent);

let VvcLinkPipe = class VvcLinkPipe {
    transform(value, options) {
        return Autolinker.link(value, options);
    }
};
VvcLinkPipe = __decorate([
    Pipe({ name: 'vvcLink' })
], VvcLinkPipe);

const components = [
    ChatMessageComponent,
    SystemMessageComponent,
    TemplateGenericComponent,
    TemplateListComponent,
    QuickRepliesComponent,
    RequestMessageComponent,
    LinkMessageComponent,
    VvcLinkPipe
];
let MessagesModule = class MessagesModule {
};
MessagesModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            VvcCommonModule
        ],
        exports: [...components],
        declarations: [...components]
    })
], MessagesModule);

let MinimizedComponent = class MinimizedComponent {
    constructor() {
        this.expand = new EventEmitter();
    }
};
__decorate([
    Input()
], MinimizedComponent.prototype, "context", void 0);
__decorate([
    Output()
], MinimizedComponent.prototype, "expand", void 0);
MinimizedComponent = __decorate([
    Component({
        selector: 'vvc-minimized',
        template: "<div (click)=\"expand.emit()\">\n  <img class='agent-img'\n       *ngIf=\"context && context.agent && context.agent.avatar\"\n       [src]=\"context && context.agent && context.agent.avatar\">\n  <img class='agent-img agent-default'\n       *ngIf=\"!context || !context.agent || !context.agent.avatar\">\n  <div class='badge' *ngIf=\"context.notRead && context.notRead > 0\">{{ context.notRead }}</div>\n\n  <audio autoplay\n         *ngIf=\"context.voiceRxStream\"\n         [srcObject]=\"context.voiceRxStream\"></audio>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], MinimizedComponent);

let MinimizedModule = class MinimizedModule {
};
MinimizedModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        exports: [
            MinimizedComponent
        ],
        declarations: [MinimizedComponent]
    })
], MinimizedModule);

let MediaComponent = class MediaComponent {
    constructor() {
        this.onAccept = new EventEmitter();
        this.onReject = new EventEmitter();
        this.onMaximize = new EventEmitter();
        this.displayChat = new EventEmitter();
        this.muteToggle = new EventEmitter();
        this.videoToggle = new EventEmitter();
        this.cameraChange = new EventEmitter();
        this.hangUp = new EventEmitter();
    }
    isMediaToolbarVisible() {
        return (this.context.videoRxStream || this.context.videoTxStream || this.context.voiceRxStream);
    }
};
__decorate([
    Input()
], MediaComponent.prototype, "context", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "onAccept", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "onReject", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "onMaximize", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "displayChat", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "muteToggle", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "videoToggle", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "cameraChange", void 0);
__decorate([
    Output()
], MediaComponent.prototype, "hangUp", void 0);
MediaComponent = __decorate([
    Component({
        selector: 'vvc-media',
        template: "<!-- closed state -->\n<div class=\"media-connected-view animated fadeInUp\" *ngIf=\"context.isClosed\">\n  <div class=\"media-content\" >\n    <div class=\"media-title\" [innerHtml]=\" 'STRINGS.VOICE.CONTACT_CLOSED' | translate | vvcSanitize:'html' \"></div>\n  </div>\n</div>\n\n<!-- offering state -->\n<div class=\"media-connected-view animated fadeInUp\" *ngIf=\"(!context.isClosed && context.isOffering)\">\n  <vvc-outgoing-offer [context]=\"context\"></vvc-outgoing-offer>\n</div>\n\n<!-- incoming state -->\n<div class=\"media-connected-view animated fadeInUp\" *ngIf=\"(!context.isClosed && context.incomingOffer)\">\n  <vvc-incoming-offer\n      [context]=\"context\"\n      (onAccept)=\"onAccept.emit($event)\"\n      (onReject)=\"onReject.emit($event)\"></vvc-incoming-offer>\n</div>\n\n<!-- connected state -->\n<div class=\"media-connected-view animated fadeInUp\" *ngIf=\"!context.isClosed && context.isMediaConnected && !context.incomingOffer\">\n\n  <div class=\"media-content\" *ngIf=\"context\">\n    <div class=\"media-title\" *ngIf=\"!(context.videoRxStream || context.videoTxStream)\" [innerHtml]=\" 'STRINGS.VOICE.WELCOME_MESSAGE' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></div>\n    <div class=\"media-avatar\" *ngIf=\"context.agent.avatar && !(context.videoRxStream || context.videoTxStream)\">\n      <img [src]=\"context.agent.avatar\">\n    </div>\n\n    <vvc-media-container\n        class=\"media-video-wrapper\"\n        (onMaximize)=\"onMaximize.emit()\"\n        (cameraChange)=\"cameraChange.emit()\"\n        [context]=\"context\"></vvc-media-container>\n    <vvc-media-toolbar\n        class=\"media-tools fit\"\n        [context]=\"context\"\n        (hangUp)=\"hangUp.emit($event)\"\n        (muteToggle)=\"muteToggle.emit($event)\"\n        (videoToggle)=\"videoToggle.emit($event)\"\n        *ngIf=\"isMediaToolbarVisible()\"></vvc-media-toolbar>\n  </div>\n  <div class=\"media-bottom animated slideInLeft\">\n    <div class=\"chat-button\"\n         (click)=\"displayChat.emit()\">\n      <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"20\" viewBox=\"0 0 20 20\" width=\"34\"><defs><path id=\"a\" d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-14 7h12v2h-12zm8 5h-8v-2h8zm4-6h-12v-2h12z\"/><mask id=\"b\" fill=\"#fff\"><use fill=\"none\" xlink:href=\"#a\"/></mask></defs><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><use fill=\"#FFF\" fill-rule=\"nonzero\" xlink:href=\"#a\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#b)\"><path d=\"m0 0h24v24h-24z\"/></g></g>\n        <circle *ngIf=\"context.notRead > 0\" fill=\"#D7293B\" cx=\"21\" cy=\"5\" r=\"5\"></circle>\n      </svg>\n      <span>{{ 'STRINGS.VOICE.OPEN_CHAT' | translate }}</span>\n    </div>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], MediaComponent);

let FullScreenVideoComponent = class FullScreenVideoComponent {
    constructor() {
        this.muteToggle = new EventEmitter();
        this.videoToggle = new EventEmitter();
        this.displayChat = new EventEmitter();
        this.hangUp = new EventEmitter();
        this.normalScreen = new EventEmitter();
        this.cameraChange = new EventEmitter();
        this.onAccept = new EventEmitter();
        this.onReject = new EventEmitter();
        this.hideLocalVideo = false;
        this.hideRemoteVideo = false;
        this.switchVideo = false;
    }
    chatToggle() {
        this.displayChat.emit(!this.context.showChatOnFullScreen);
    }
    isMediaToolbarVisible() {
        return (this.context.videoRxStream || this.context.videoTxStream || this.context.voiceRxStream);
    }
};
__decorate([
    Input()
], FullScreenVideoComponent.prototype, "context", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "muteToggle", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "videoToggle", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "displayChat", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "hangUp", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "normalScreen", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "cameraChange", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "onAccept", void 0);
__decorate([
    Output()
], FullScreenVideoComponent.prototype, "onReject", void 0);
FullScreenVideoComponent = __decorate([
    Component({
        selector: 'vvc-full-screen-video',
        template: "<div class=\"chat-toggle\" (click)=\"chatToggle()\">\n  <div class=\"chat-opened\" *ngIf=\"context.showChatOnFullScreen\">\n    <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"20\" viewBox=\"0 0 20 20\" width=\"20\"><mask id=\"a\" fill=\"#fff\"><path d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-8 9.4142136-3.53553391 3.5355339-1.41421356-1.4142136 3.53553387-3.5355339-3.53553387-3.53553391 1.41421356-1.41421356 3.53553391 3.53553391 3.5355339-3.53553391 1.4142136 1.41421356-3.5355339 3.53553391 3.5355339 3.5355339-1.4142136 1.4142136z\" fill=\"#fff\"/></mask><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#a)\"><path d=\"m0 0h24v24h-24z\"/></g></g></svg>\n  </div>\n  <div class=\"chat-closed\" *ngIf=\"!context.showChatOnFullScreen\">\n    <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" height=\"20\" viewBox=\"0 0 20 20\" width=\"34\"><defs><path id=\"a\" d=\"m20 2h-16c-1.1 0-1.99.9-1.99 2l-.01 18 4-4h14c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm-14 7h12v2h-12zm8 5h-8v-2h8zm4-6h-12v-2h12z\"/><mask id=\"b\" fill=\"#fff\"><use fill=\"none\" xlink:href=\"#a\"/></mask></defs><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24z\"/><use fill=\"#FFF\" fill-rule=\"nonzero\" xlink:href=\"#a\"/><g fill=\"#fff\" fill-rule=\"evenodd\" mask=\"url(#b)\"><path d=\"m0 0h24v24h-24z\"/></g></g>\n      <circle *ngIf=\"context.notRead > 0\" fill=\"#D7293B\" cx=\"21\" cy=\"5\" r=\"5\"></circle>\n    </svg>\n  </div>\n</div>\n\n<vvc-media-container\n    class=\"media-video-wrapper full-screen\"\n    (normalScreen)=\"normalScreen.emit()\"\n    (cameraChange)=\"cameraChange.emit()\"\n    [context]=\"context\"></vvc-media-container>\n\n<div class=\"media-controls-wrapper\" *ngIf=\"isMediaToolbarVisible()\">\n  <vvc-media-toolbar\n      class=\"media-tools\"\n      [context]=\"context\"\n      (hangUp)=\"hangUp.emit($event)\"\n      (muteToggle)=\"muteToggle.emit($event)\"\n      (videoToggle)=\"videoToggle.emit($event)\"></vvc-media-toolbar>\n</div>\n\n<div class=\"media-modal\" *ngIf=\"(!context.isClosed && context.incomingOffer)\">\n  <div class=\"spacer\"></div>\n  <div class=\"media-connected-view animated fadeInUp\">\n    <vvc-incoming-offer\n        [context]=\"context\"\n        (onAccept)=\"onAccept.emit($event)\"\n        (onReject)=\"onReject.emit($event)\"></vvc-incoming-offer>\n  </div>\n  <div class=\"spacer\"></div>\n</div>\n\n<div class=\"media-modal\" *ngIf=\"(!context.isClosed && context.isOffering)\">\n  <div class=\"spacer\"></div>\n  <div class=\"media-connected-view animated fadeInUp\">\n    <vvc-outgoing-offer [context]=\"context\"></vvc-outgoing-offer>\n  </div>\n  <div class=\"spacer\"></div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], FullScreenVideoComponent);

let MediaContainerComponent = class MediaContainerComponent {
    constructor(cd) {
        this.cd = cd;
        this.onMaximize = new EventEmitter();
        this.normalScreen = new EventEmitter();
        this.cameraChange = new EventEmitter();
        this.hideSmallVideo = false;
        this.switchVideo = false;
        this.showVideoIsPaused = false;
        this.userAction = false;
        this.ngAfterViewInited = false;
    }
    ngAfterViewInit() {
        this.ngAfterViewInited = true;
        this.cd.detectChanges();
        if (!this.context.videoRxStream &&
            !this.context.videoTxStream &&
            this.context.screenRxStream &&
            this.bigVideo &&
            this.bigVideo.nativeElement.paused) {
            this.bigVideo.nativeElement.muted = true;
            this.cd.detectChanges();
        }
    }
    canHideSmallVideo() {
        return !this.hideSmallVideo && (this.isLocalVideoVisible || this.isRemoteVideoVisible);
    }
    canShowSmallVideo() {
        return this.hideSmallVideo && (this.isLocalVideoVisible || this.isRemoteVideoVisible);
    }
    get bigVideoSrc() {
        if (this.ngAfterViewInited) {
            if (this.switchVideo) {
                return this.context.videoRxStream || this.context.screenRxStream || this.context.videoTxStream;
            }
            else {
                return this.context.screenRxStream || this.context.videoRxStream || this.context.videoTxStream;
            }
        }
    }
    get localVideoSrc() {
        if (this.ngAfterViewInited) {
            return this.context.videoTxStream;
        }
    }
    get remoteVideoSrc() {
        if (this.ngAfterViewInited) {
            if (this.switchVideo) {
                return this.context.screenRxStream || this.context.videoRxStream;
            }
            else {
                return this.context.videoRxStream;
            }
        }
    }
    hasMultipleVideoDevice() {
        return !!this.context.hasMultipleVideoDevice;
    }
    get isBigVideoVisible() {
        return this.context && (this.context.screenRxStream ||
            this.context.videoRxStream ||
            (!this.context.screenRxStream && !this.context.videoRxStream && this.context.videoTxStream));
    }
    get isLocalVideoVisible() {
        return this.context && this.context.videoTxStream && (this.context.screenRxStream || this.context.videoRxStream);
    }
    get isRemoteVideoVisible() {
        return this.context && this.context.screenRxStream && this.context.videoRxStream;
    }
    isFlipped() {
        return !this.context.screenRxStream && !this.context.videoRxStream && this.context.videoTxStream;
    }
    minMaxVideo() {
        (this.context.isFullScreen) ? this.normalScreen.emit() : this.onMaximize.emit();
    }
    playVideo() {
        if (this.ngAfterViewInited) {
            this.userAction = true;
            this.showVideoIsPaused = false;
            if (this.bigVideo && this.bigVideo.nativeElement) {
                if (this.bigVideo.nativeElement.srcObject !== this.context.videoTxStream) {
                    this.bigVideo.nativeElement.muted = false;
                }
                else {
                    this.bigVideo.nativeElement.muted = true;
                }
                if (this.bigVideo.nativeElement.paused) {
                    this.bigVideo.nativeElement.play();
                }
            }
            if (this.localVideo && this.localVideo.nativeElement && this.localVideo.nativeElement.paused) {
                this.localVideo.nativeElement.play();
            }
            if (this.remoteVideo && this.remoteVideo.nativeElement && this.remoteVideo.nativeElement.paused) {
                this.remoteVideo.nativeElement.play();
            }
        }
    }
    get showLocalVideo() {
        return !this.hideSmallVideo && this.isLocalVideoVisible;
    }
    get showRemoteVideo() {
        return !this.hideSmallVideo && this.isRemoteVideoVisible;
    }
    toggleCamera() {
        this.cameraChange.emit();
    }
    toggleSmallVideo() {
        this.hideSmallVideo = !this.hideSmallVideo;
    }
    switchBigVideo() {
        this.switchVideo = !this.switchVideo;
    }
    videoOnPause(videoId, evt) {
        // console.log('videoOnPause', videoId, evt);
        this.showVideoIsPaused = true;
    }
    logVideoEvent(videoId, evt) {
        // console.log('logVideoEvent', videoId, evt);
    }
};
MediaContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], MediaContainerComponent.prototype, "context", void 0);
__decorate([
    Output()
], MediaContainerComponent.prototype, "onMaximize", void 0);
__decorate([
    Output()
], MediaContainerComponent.prototype, "normalScreen", void 0);
__decorate([
    Output()
], MediaContainerComponent.prototype, "cameraChange", void 0);
__decorate([
    ViewChild('bigVideo', { static: true })
], MediaContainerComponent.prototype, "bigVideo", void 0);
__decorate([
    ViewChild('localVideo', { static: true })
], MediaContainerComponent.prototype, "localVideo", void 0);
__decorate([
    ViewChild('remoteVideo', { static: true })
], MediaContainerComponent.prototype, "remoteVideo", void 0);
MediaContainerComponent = __decorate([
    Component({
        selector: 'vvc-media-container',
        template: "<div class=\"media-containers\">\n  <div class=\"video-paused\" *ngIf=\"showVideoIsPaused\">\n    {{ 'STRINGS.MEDIA.VIDEO_STOPPED' | translate }}\n    <div class=\"btn\">\n      <button (click)=\"playVideo()\">{{'STRINGS.MEDIA.VIDEO_CONTINUE' | translate }}</button>\n    </div>\n  </div>\n  <div class=\"size-tools\" [ngClass]=\"{ 'desktop' : !context.isMobile }\">\n    <span class=\"buttons\"\n          *ngIf=\"context.isFullScreen\"\n          (click)=\"normalScreen.emit()\">\n      <svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-4 -4)\"><path d=\"m0 0h24v24h-24z\"></path><path d=\"m8.66666667 8.66666667v-4.66666667h1.73333333v6.4h-6.4v-1.73333333zm6.66666663 0h4.6666667v1.73333333h-6.4v-6.4h1.7333333zm-6.66666663 6.66666663h-4.66666667v-1.7333333h6.4v6.4h-1.73333333zm6.66666663 0v4.6666667h-1.7333333v-6.4h6.4v1.7333333z\" fill=\"#fff\"></path></g></svg>\n      <span class=\"tooltip\">{{ 'STRINGS.MEDIA.TOOLTIPS.MINIMIZE_VIDEO' | translate }}</span>\n    </span>\n    <span class=\"buttons\"\n          *ngIf=\"!context.isFullScreen\"\n          (click)=\"onMaximize.emit()\">\n      <svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-4 -4)\"><path d=\"m0 0h24v24h-24z\"></path><path d=\"m5.6 5.6v4.8h-1.6v-6.4h6v1.6zm12.8 0h-4.8v-1.6h6.4v6.4h-1.6zm-12.8 12.8h4.4v1.6h-6v-6.4h1.6zm12.8 0v-4.8h1.6v6.4h-6v-1.6z\" fill=\"#fff\"></path></g></svg>\n      <span class=\"tooltip\">{{ 'STRINGS.MEDIA.TOOLTIPS.MAXIMIZE_VIDEO' | translate }}</span>\n    </span>\n    <span class=\"buttons\"\n          *ngIf=\"canHideSmallVideo()\"\n          (click)=\"toggleSmallVideo()\">\n      <svg height=\"16\" viewBox=\"0 0 20 16\" width=\"20\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -4)\"><path d=\"m0 0h24v24h-24z\"></path><path d=\"m20 4h-16c-1.1 0-1.99.9-1.99 2l-.01 12c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2v-12c0-1.1-.9-2-2-2zm0 14h-16v-9h16zm0-11h-16v1h16z\" fill=\"#fff\"></path></g></svg>\n      <span class=\"tooltip\">{{ 'STRINGS.MEDIA.TOOLTOPS.HIDE_VIDEOS' | translate }}</span>\n    </span>\n    <span class=\"buttons\"\n          *ngIf=\"canShowSmallVideo()\"\n          (click)=\"toggleSmallVideo()\">\n      <svg height=\"16\" viewBox=\"0 0 20 16\" width=\"20\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -4)\"><path d=\"m0 0h24v24h-24z\"></path><path d=\"m20 4c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2h-16c-1.1 0-2-.9-2-2l.01-12c0-1.1.89-2 1.99-2zm-11 13h-4v-4h4zm10 0h-4v-4h4zm1 1v-9h-16v9zm0-11h-16v1h16z\" fill=\"#fff\"></path></g></svg>\n      <span class=\"tooltip\">{{ 'STRINGS.MEDIA.TOOLTOPS.SHOW_VIDEOS' | translate }}</span>\n    </span>\n    <span class=\"buttons\"\n          *ngIf=\"isRemoteVideoVisible\"\n          (click)=\"switchBigVideo()\">\n      <svg height=\"16\" viewBox=\"0 0 16 16\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-4 -4)\"><path d=\"m0 0h24v24h-24z\"></path><path d=\"m18.4885389 20-3.4951324-3.5-1.9972185 2v-5.5h5.4923509l-1.9972185 2 3.5019027 3.5652797zm-12.99062501-16 3.50190271 3.5 1.9972185-2v5.5h-5.4923509l1.99721852-2-3.50190272-3.5z\" fill=\"#fff\"></path></g></svg>\n      <span class=\"tooltip\" *ngIf=\"switchVideo\">{{ 'STRINGS.MEDIA.TOOLTOPS.SWITCH_REMOTE_SHARING' | translate }}</span>\n      <span class=\"tooltip\" *ngIf=\"!switchVideo\">{{ 'STRINGS.MEDIA.TOOLTOPS.SWITCH_SHARING_REMOTE' | translate }}</span>\n    </span>\n    <span class=\"buttons\"\n          *ngIf=\"hasMultipleVideoDevice()\"\n          (click)=\"toggleCamera()\">\n      <svg height=\"18\" viewBox=\"0 0 20 18\" width=\"20\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -3)\"><path d=\"m0 0h24v24h-24z\" fill-rule=\"nonzero\" opacity=\"0\"/><path d=\"m16.83 5h3.17c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2h-16c-1.1 0-2-.9-2-2v-12c0-1.1.9-2 2-2h3.17l1.83-2h6zm-.83 8c0 2.209139-1.790861 4-4 4-.8124333 0-1.5682955-.2422095-2.19931625-.6583581l-1.20532289 1.5995175c.96730056.6677735 2.14030054 1.0588406 3.40463914 1.0588406 3.3137085 0 6-2.6862915 6-6h2l-3-4-3 4zm-10 0h-2l3 4 3-4h-2c0-2.209139 1.790861-4 4-4 .7718298 0 1.4926018.21860439 2.1037785.59727567l1.2070959-1.60187029c-.9489218-.62903706-2.0871132-.99540538-3.3108744-.99540538-3.3137085 0-6 2.6862915-6 6z\" fill=\"#fff\"/></g></svg>\n      <span class=\"tooltip\">{{ 'STRINGS.MEDIA.TOOLTIPS.TOGGLE_CAMERA' | translate }}</span>\n    </span>\n\n  </div>\n  <audio autoplay\n         *ngIf=\"context.voiceRxStream && !context.videoRxStream\"\n         [srcObject]=\"context.voiceRxStream\"></audio>\n\n  <div class=\"big-video\"\n       [hidden]=\"!isBigVideoVisible\"\n       (dblclick)=\"minMaxVideo()\">\n    <video autoplay playsinline\n           #bigVideo\n           (play)=\"playVideo()\"\n           (playing)=\"logVideoEvent('big-video', $event)\"\n           (pause)=\"videoOnPause('big-video', $event)\"\n           (volumechange)=\"logVideoEvent('big-video', $event)\"\n           [srcObject]=\"bigVideoSrc\"></video>\n  </div>\n  <div class=\"small-video local\"\n       *ngIf=\"showLocalVideo\">\n    <video autoplay playsinline\n           #localVideo\n           (play)=\"logVideoEvent('local-video', $event)\"\n           (playing)=\"logVideoEvent('local-video', $event)\"\n           (pause)=\"videoOnPause('local-video', $event)\"\n           (volumechange)=\"logVideoEvent('local-video', $event)\"\n           [muted]=\"true\"\n           [srcObject]=\"localVideoSrc\"></video>\n  </div>\n  <div class=\"small-video remote\"\n       *ngIf=\"showRemoteVideo\"\n       (click)=\"switchBigVideo()\">\n    <video autoplay playsinline\n           #remoteVideo\n           (play)=\"logVideoEvent('remote-video', $event)\"\n           (playing)=\"logVideoEvent('remote-video', $event)\"\n           (pause)=\"videoOnPause('remote-video', $event)\"\n           (volumechange)=\"logVideoEvent('remote-video', $event)\"\n           [srcObject]=\"remoteVideoSrc\"></video>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], MediaContainerComponent);

let MediaToolbarComponent = class MediaToolbarComponent {
    constructor() {
        this.muteToggle = new EventEmitter();
        this.videoToggle = new EventEmitter();
        this.hangUp = new EventEmitter();
    }
    hangup() {
        this.hangUp.emit();
    }
    toggleMute() {
        this.muteToggle.emit(!this.context.isMuted);
    }
    toggleVideo() {
        if (this.context.inVideoTransit) {
            return;
        }
        this.videoToggle.emit(!this.context.videoTxStream);
    }
};
__decorate([
    Input()
], MediaToolbarComponent.prototype, "context", void 0);
__decorate([
    Output()
], MediaToolbarComponent.prototype, "muteToggle", void 0);
__decorate([
    Output()
], MediaToolbarComponent.prototype, "videoToggle", void 0);
__decorate([
    Output()
], MediaToolbarComponent.prototype, "hangUp", void 0);
MediaToolbarComponent = __decorate([
    Component({
        selector: 'vvc-media-toolbar',
        template: "<div class=\"button-wrapper\">\n  <div class=\"round-button\"\n       *ngIf=\"!context.isMuted\"\n       (click)=\"toggleMute()\">\n    <svg height=\"19\" viewBox=\"0 0 14 19\" width=\"14\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m12 14c1.66 0 2.99-1.34 2.99-3l.01-6c0-1.66-1.34-3-3-3s-3 1.34-3 3v6c0 1.66 1.34 3 3 3zm5.3-3c0 3-2.54 5.1-5.3 5.1s-5.3-2.1-5.3-5.1h-1.7c0 3.41 2.72 6.23 6 6.72v3.28h2v-3.28c3.28-.48 6-3.3 6-6.72z\" class=\"fill\" transform=\"translate(-5 -2)\"/></svg>\n  </div>\n  <div *ngIf=\"!context.isMuted\" class=\"button-label\">{{ 'STRINGS.MEDIA.UNMUTED' | translate }}</div>\n  <div class=\"round-button\"\n       *ngIf=\"context.isMuted\"\n       (click)=\"toggleMute()\">\n    <svg height=\"19\" viewBox=\"0 0 18 19\" width=\"18\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-3 -2)\"><path d=\"m0 0h24v24h-24zm0 0h24v24h-24z\"/><path d=\"m19 11h-1.7c0 .74-.16 1.43-.43 2.05l1.23 1.23c.56-.98.9-2.09.9-3.28zm-4.02.17c0-.06.02-.11.02-.17v-6c0-1.66-1.34-3-3-3s-3 1.34-3 3v.18zm-10.71-8.17-1.27 1.27 6.01 6.01v.72c0 1.66 1.33 3 2.99 3 .22 0 .44-.03.65-.08l1.66 1.66c-.71.33-1.5.52-2.31.52-2.76 0-5.3-2.1-5.3-5.1h-1.7c0 3.41 2.72 6.23 6 6.72v3.28h2v-3.28c.91-.13 1.77-.45 2.54-.9l4.19 4.18 1.27-1.27z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n  </div>\n  <div *ngIf=\"context.isMuted\" class=\"button-label\">{{ 'STRINGS.MEDIA.MUTED' | translate }}</div>\n</div>\n<div class=\"button-wrapper\">\n  <div class=\"round-button\"\n       *ngIf=\"!context.videoTxStream\"\n       (click)=\"toggleVideo()\">\n    <svg height=\"19\" viewBox=\"0 0 19 19\" width=\"19\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-2 -2)\"><path d=\"m0 0h24v24h-24zm0 0h24v24h-24z\"/><path d=\"m21 6.5-4 4v-3.5c0-.55-.45-1-1-1h-6.18l11.18 11.18zm-17.73-4.5-1.27 1.27 2.73 2.73h-.73c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h12c.21 0 .39-.08.54-.18l3.19 3.18 1.27-1.27z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n  </div>\n  <div *ngIf=\"!context.videoTxStream\" class=\"button-label\">{{ 'STRINGS.MEDIA.VIDEO_DISABLED' | translate }}</div>\n  <div class=\"round-button\"\n       *ngIf=\"context.videoTxStream\"\n       (click)=\"toggleVideo()\">\n    <svg height=\"12\" viewBox=\"0 0 18 12\" width=\"18\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-3 -6)\"><path d=\"m0 0h24v24h-24z\"/><path d=\"m17 10.5v-3.5c0-.55-.45-1-1-1h-12c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-3.5l4 4v-11z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n  </div>\n  <div *ngIf=\"context.videoTxStream\" class=\"button-label\">{{ 'STRINGS.MEDIA.VIDEO_ENABLED' | translate }}</div>\n</div>\n<div class=\"button-wrapper\">\n  <div class=\"round-button hangup\" (click)=\"hangup()\">\n    <svg height=\"8\" viewBox=\"0 0 22 8\" width=\"22\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-1 -8)\"><path d=\"m0 0h24.000001v24.000001h-24.000001zm0 0h24.000001v24.000001h-24.000001z\"/><path d=\"m7.83689909 10.3913551v2.7170978c0 .3458124-.19583633.6360478-.48643218.7842532-.94127785.4631416-1.8257 1.0806639-2.61536263 1.8525666-.34745156.3396372-.91600865.3396372-1.26346021 0l-2.21105536-2.1613277c-.34745156-.3396373-.34745156-.8954073 0-1.2350445 5.93194567-5.79853359 15.54687789-5.79853359 21.47882349 0 .3474516.3396372.3474516.8954072 0 1.2350445l-2.204738 2.1551525c-.3474516.3396372-.9160087.3396372-1.2634602 0-.7833454-.7657275-1.6740848-1.389425-2.6153627-1.8525667-.2969131-.1420301-.4927494-.4446159-.4927494-.7780779v-2.7170978c-2.7038049-.85218066-5.6287153-.85835588-8.32620281 0z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n  </div>\n  <div class=\"button-label\">{{ 'STRINGS.MEDIA.CLOSE_CALL' | translate }}</div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], MediaToolbarComponent);

let IncomingOfferComponent = class IncomingOfferComponent {
    constructor() {
        this.onAccept = new EventEmitter();
        this.onReject = new EventEmitter();
    }
    acceptOffer() {
        this.onAccept.emit();
    }
    rejectIncomingOffer() {
        this.onReject.emit();
    }
};
__decorate([
    Input()
], IncomingOfferComponent.prototype, "context", void 0);
__decorate([
    Output()
], IncomingOfferComponent.prototype, "onAccept", void 0);
__decorate([
    Output()
], IncomingOfferComponent.prototype, "onReject", void 0);
IncomingOfferComponent = __decorate([
    Component({
        selector: 'vvc-incoming-offer',
        template: "<div class=\"media-content\" >\n  <div class=\"media-title\" [innerHtml]=\" 'STRINGS.VOICE.INCOMING_MESSAGE' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></div>\n  <div class=\"media-avatar\" *ngIf=\"context.agent.avatar\">\n    <img [src]=\"context.agent.avatar\">\n  </div>\n  <div class=\"media-tools fit incoming\">\n    <div class=\"button-wrapper\">\n      <div class=\"round-button hangup\" (click)=\"rejectIncomingOffer()\">\n        <svg height=\"8\" viewBox=\"0 0 22 8\" width=\"22\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-1 -8)\"><path d=\"m0 0h24.000001v24.000001h-24.000001zm0 0h24.000001v24.000001h-24.000001z\"/><path d=\"m7.83689909 10.3913551v2.7170978c0 .3458124-.19583633.6360478-.48643218.7842532-.94127785.4631416-1.8257 1.0806639-2.61536263 1.8525666-.34745156.3396372-.91600865.3396372-1.26346021 0l-2.21105536-2.1613277c-.34745156-.3396373-.34745156-.8954073 0-1.2350445 5.93194567-5.79853359 15.54687789-5.79853359 21.47882349 0 .3474516.3396372.3474516.8954072 0 1.2350445l-2.204738 2.1551525c-.3474516.3396372-.9160087.3396372-1.2634602 0-.7833454-.7657275-1.6740848-1.389425-2.6153627-1.8525667-.2969131-.1420301-.4927494-.4446159-.4927494-.7780779v-2.7170978c-2.7038049-.85218066-5.6287153-.85835588-8.32620281 0z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n      </div>\n      <div class=\"button-label\">{{ 'STRINGS.MEDIA.DECLINE' | translate }}</div>\n    </div>\n\n    <div class=\"button-wrapper\">\n      <div class=\"round-button\"\n           (click)=\"acceptOffer()\">\n        <svg *ngIf=\"context.incomingMedia === 'Video'\" height=\"12\" viewBox=\"0 0 18 12\" width=\"18\" xmlns=\"http://www.w3.org/2000/svg\"><g fill=\"none\" fill-rule=\"evenodd\" transform=\"translate(-3 -6)\"><path d=\"m0 0h24v24h-24z\"/><path d=\"m17 10.5v-3.5c0-.55-.45-1-1-1h-12c-.55 0-1 .45-1 1v10c0 .55.45 1 1 1h12c.55 0 1-.45 1-1v-3.5l4 4v-11z\" class=\"fill\" fill-rule=\"nonzero\"/></g></svg>\n        <svg *ngIf=\"context.incomingMedia === 'Voice'\" height=\"18\" viewBox=\"0 0 18 18\" width=\"18\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m17.38 10.79-2.2-2.2c-.28-.28-.36-.67-.25-1.02.37-1.12.57-2.32.57-3.57 0-.55.45-1 1-1h3.5c.55 0 1 .45 1 1 0 9.39-7.61 17-17 17-.55 0-1-.45-1-1v-3.49c0-.55.45-1 1-1 1.24 0 2.45-.2 3.57-.57.35-.12.75-.03 1.02.24l2.2 2.2c2.83-1.45 5.15-3.76 6.59-6.59z\" class=\"fill\" transform=\"translate(-3 -3)\"/></svg>\n      </div>\n      <div class=\"button-label\">{{ 'STRINGS.MEDIA.ACCEPT' | translate }}</div>\n    </div>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], IncomingOfferComponent);

let OutgoingOfferComponent = class OutgoingOfferComponent {
};
__decorate([
    Input()
], OutgoingOfferComponent.prototype, "context", void 0);
OutgoingOfferComponent = __decorate([
    Component({
        selector: 'vvc-outgoing-offer',
        template: "<div class=\"media-content\" >\n  <div class=\"media-title\" [innerHtml]=\" 'STRINGS.VOICE.MEDIA_OFFERING' | translate:{ nickname: context.agent.nick } | vvcSanitize:'html' \"></div>\n  <div class=\"media-avatar\" *ngIf=\"context.agent.avatar\">\n    <img [src]=\"context.agent.avatar\">\n  </div>\n  <div class=\"media-loading\">\n    <div class=\"inner-loading-panel\">\n      <div class=\"loading-container\">\n        <div class=\"progress-bar\">\n          <div class=\"loaded\"></div>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], OutgoingOfferComponent);

let MultimediaModule = class MultimediaModule {
};
MultimediaModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            VvcCommonModule
        ],
        exports: [MediaComponent, FullScreenVideoComponent],
        declarations: [
            MediaComponent,
            FullScreenVideoComponent,
            MediaContainerComponent,
            MediaToolbarComponent,
            IncomingOfferComponent,
            OutgoingOfferComponent
        ]
    })
], MultimediaModule);

let QueueComponent = class QueueComponent {
};
__decorate([
    Input()
], QueueComponent.prototype, "context", void 0);
QueueComponent = __decorate([
    Component({
        selector: 'vvc-queue',
        template: "<div class=\"queue-view\">\n  <div *ngIf=\"!context.hasError\">\n    <div class=\"queue-message animated fadeInUp\" [innerHtml]=\" 'STRINGS.QUEUE.CONNECTING' | translate \">\n    </div>\n    <div class=\"queue-loading animated fadeInUp\">\n      <div class=\"inner-loading-panel\">\n        <div class=\"loading-container\">\n          <div class=\"progress-bar\">\n            <div class=\"loaded\"></div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <div *ngIf=\"context.hasError\">\n    <div *ngIf=\"!context.contactCreationFailed && !context.webleadSent\" class=\"queue-message animated fadeInUp\" [innerHtml]=\" 'STRINGS.QUEUE.DISSUASION' | translate \"></div>\n    <div *ngIf=\"!context.contactCreationFailed && context.webleadSent\" class=\"queue-message animated fadeInUp\" [innerHtml]=\" 'STRINGS.QUEUE.WEBLEAD_SENT' | translate \"></div>\n    <div *ngIf=\"context.contactCreationFailed && !context.contactCreationNoAgents\" class=\"queue-message animated fadeInUp\" [innerHtml]=\" 'STRINGS.QUEUE.CONTACT_FAILED' | translate \"></div>\n    <div *ngIf=\"context.contactCreationFailed && context.contactCreationNoAgents\" class=\"queue-message animated fadeInUp\" [innerHtml]=\" 'STRINGS.QUEUE.NO_AGENTS' | translate \"></div>\n  </div>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], QueueComponent);

let QueueModule = class QueueModule {
};
QueueModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule
        ],
        exports: [
            QueueComponent
        ],
        declarations: [QueueComponent]
    })
], QueueModule);

let TopBarComponent = class TopBarComponent {
    constructor() {
        this.onMinimize = new EventEmitter();
        this.onClose = new EventEmitter();
        this.onSurvey = new EventEmitter();
        this.onRemove = new EventEmitter();
        this.onHideChat = new EventEmitter();
        this.onVoiceUpgrade = new EventEmitter();
        this.onVideoUpgrade = new EventEmitter();
        this.onMaximize = new EventEmitter();
        this.isMenuVisible = false;
        this.closeAttempts = 0;
    }
    closeContact() {
        this.onClose.emit();
    }
    closeMenu() {
        this.isMenuVisible = false;
    }
    hasMenu() {
        let itemNumber = 0;
        if (this.context && !this.context.isMediaConnecting && !this.context.cbnMode) {
            if (this.context.canMinimize) {
                itemNumber++;
            }
            if (this.context.canStartAudio && !this.context.isMediaConnected) {
                itemNumber++;
            }
            if (this.context.canStartVideo && !this.context.isMediaConnected) {
                itemNumber++;
            }
            if ((this.context.isMediaMinimized && this.context.isMediaConnected) && !this.context.isAutoChat) {
                itemNumber++;
            }
        }
        return (itemNumber > 1);
    }
    removeApp() {
        this.closeContact();
    }
    showMenu() {
        this.isMenuVisible = true;
    }
};
__decorate([
    Input()
], TopBarComponent.prototype, "context", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onMinimize", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onClose", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onSurvey", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onRemove", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onHideChat", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onVoiceUpgrade", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onVideoUpgrade", void 0);
__decorate([
    Output()
], TopBarComponent.prototype, "onMaximize", void 0);
TopBarComponent = __decorate([
    Component({
        selector: 'vvc-top-bar',
        template: "<div id=\"vvc-top-bar\">\n  <div id=\"vvc-top-avatar\" *ngIf=\"context.topBarAvatar\"><img [src]=\"context.topBarAvatar\"></div>\n  <div id=\"vvc-top-header\">\n    <div id=\"vvc-top-title\">{{ context.topBarTitle | translate }}</div>\n    <div id=\"vvc-top-subtitle\">{{ context.topBarSubtitle | translate }}</div>\n  </div>\n  <div class=\"vvc-top-controls\" *ngIf=\"context.canRemoveApp && !context.incomingOffer\">\n    <span (click)=\"removeApp()\">\n      <i class=\"icon icon-vvc-close\"></i>\n    </span>\n  </div>\n  <div class=\"vvc-top-controls\" *ngIf=\"!hasMenu() && !context.canRemoveApp && !context.incomingOffer\">\n    <span *ngIf=\"context.canMinimize\" (click)=\"onMinimize.emit()\">\n      <i class=\"icon icon-vvc-reduce\"></i>\n    </span>\n    <span (click)=\"closeContact()\">\n      <i class=\"icon icon-vvc-close\"></i>\n    </span>\n  </div>\n  <div class=\"vvc-top-controls\" *ngIf=\"hasMenu() && !context.canRemoveApp && !context.incomingOffer\">\n    <span (click)=\"showMenu()\">\n      <i class=\"icon icon-vvc-menu\"></i>\n    </span>\n  </div>\n  <div id=\"vvc-top-bar-menu\" *ngIf=\"isMenuVisible\" (click)=\"closeMenu()\">\n    <div id=\"vvc-menu-inner\" class=\"animated\" [ngClass]=\"{ 'fadeIn': isMenuVisible }\">\n      <div *ngIf=\"context.isMediaMinimized && context.isMediaConnected && !context.isFullScreen\" (click)=\"onHideChat.emit()\">\n        <span><i class=\"icon icon-vvc-chat\"></i> {{ 'STRINGS.QUEUE.TOPBAR.HIDE_CHAT_BUTTON' | translate }}</span>\n      </div>\n      <div *ngIf=\"context.canStartAudio\" (click)=\"onVoiceUpgrade.emit()\">\n        <span><i class=\"icon icon-vvc-audio\"></i> {{ 'STRINGS.QUEUE.TOPBAR.VOICE_BUTTON' | translate }}</span>\n      </div>\n      <div *ngIf=\"context.canStartVideo && !context.isMediaConnected\" (click)=\"onVideoUpgrade.emit()\">\n        <span><i class=\"icon icon-vvc-video\"></i> {{ 'STRINGS.QUEUE.TOPBAR.VIDEO_BUTTON' | translate }}</span>\n      </div>\n      <div *ngIf=\"context.canMinimize\" (click)=\"onMinimize.emit()\">\n        <span><i class=\"icon icon-vvc-reduce\"></i> {{ 'STRINGS.QUEUE.TOPBAR.MINIMIZE_BUTTON' | translate }}</span>\n      </div>\n      <div (click)=\"closeContact()\">\n        <span><i class=\"icon icon-vvc-close\"></i> {{ 'STRINGS.QUEUE.TOPBAR.CLOSE_BUTTON' | translate }}</span>\n      </div>\n    </div>\n  </div>\n</div>",
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], TopBarComponent);

let TopBarModule = class TopBarModule {
};
TopBarModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule
        ],
        exports: [
            TopBarComponent
        ],
        declarations: [TopBarComponent]
    })
], TopBarModule);

/*
 * Public API Surface of client-interaction-layout
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CbnModule, ChatAreaComponent, ChatComponent, ChatIsWritingComponent, ChatModule, ChatPanelsModule, ClosePanelModule, DataCollectionModule, InboundModule, LoadingPanelModule, MessagesModule, MinimizedModule, MultimediaModule, QueueModule, TopBarComponent, TopBarModule, VvcCommonModule as ɵa, VvcSanitizePipe as ɵb, MediaComponent as ɵba, FullScreenVideoComponent as ɵbb, MediaContainerComponent as ɵbc, MediaToolbarComponent as ɵbd, IncomingOfferComponent as ɵbe, OutgoingOfferComponent as ɵbf, QueueComponent as ɵbg, InboundComponent as ɵc, InboundTopbarComponent as ɵd, InboundFullscreenMessagesComponent as ɵe, CbnComponent as ɵf, CbnMinimizedComponent as ɵg, CbnTopbarComponent as ɵh, CbnFullscreenMessagesComponent as ɵi, CbnMinimizedMessagesComponent as ɵj, VvcAutoScrollDirective as ɵk, EmojiPanelComponent as ɵl, UploadPanelComponent as ɵm, ClosePanelComponent as ɵn, DataCollectionComponent as ɵo, FormComponent as ɵp, LoadingPanelComponent as ɵq, ChatMessageComponent as ɵr, SystemMessageComponent as ɵs, TemplateGenericComponent as ɵt, TemplateListComponent as ɵu, QuickRepliesComponent as ɵv, RequestMessageComponent as ɵw, LinkMessageComponent as ɵx, VvcLinkPipe as ɵy, MinimizedComponent as ɵz };
//# sourceMappingURL=vivocha-client-interaction-layout.js.map
